clear all
close all
clc

datapath = '../output/Period3_Target/';%change data path here
%% 
load(strcat(datapath, 'ests_x.mat'))%this is MCMC output
%% 
rawData = readmatrix("../input/model_input_mcmc_new.xlsx"); %this is the real data

raw_n2 = rawData(:,5);
raw_tau = rawData(:,6);
raw_mandatory = rawData(:,8);
raw_selection = rawData(:,7);
raw_CJR = rawData(:,3);
raw_strata = rawData(:,4);

vol_n = raw_n2(raw_CJR==1 & raw_mandatory==0);
vol_tau = raw_tau(raw_CJR==1 & raw_mandatory==0);
vol_sel = raw_selection(raw_CJR==1 & raw_mandatory==0);
%% Cut Burn-in
burnin_point = 10000;
for cv = who('*_finish')' %transpose to get a row cell array
  eval(sprintf('%1$s = %1$s(:,[burnin_point+1:size(%1$s,2)]);', cv{1})); %1$s is replaced by var name, output is named meanvarname
end
%% Calculate t_bar 
xx_wMean = @(x,w) sum(x.*w)./sum(w);
t_bar = xx_wMean(exp(vol_tau),vol_n);
%% Figure 4
sig_eps_S = 1 ./ sqrt(tau_e_finish);
seed = 99;
rng(seed)
zeta_h = mvnrnd(0, 1, size(lnlambda_finish,1));
epsilon3_hS = zeta_h.*sig_eps_S;

exp_lam3_hS = exp(lnlambda_finish + gamma3_finish + epsilon3_hS);
exp_ome_hS = exp(lnomega_finish);

exp_lam3_h = mean(exp_lam3_hS,2);
exp_ome_h = mean(exp_ome_hS,2);

exp_lam3_h_vol = exp_lam3_h(raw_CJR==1 & raw_mandatory==0);
exp_ome_h_vol = exp_ome_h(raw_CJR==1 & raw_mandatory==0);

lam3_sim_one = exp_lam3_h_vol;
ome_sim_one = exp_ome_h_vol;
tau_sim_one = exp(vol_tau);
n_sim_one = vol_n;
%% 
rng(seed+1) %%randomly select N_dots of hospitals to draw in the figure
N_dots = 150;
A3 = zeros(length(lam3_sim_one),1); 
A3(1:N_dots) = 1; 
A3(randperm(numel(A3))) = A3;
A3 = A3==1;

delta = 0.15;
lambda1_orig = linspace(t_bar, 2 * t_bar, 100);
lambda2_orig = linspace(-2e4, t_bar - 1/delta, 100);
omega1_orig = 2 * lambda1_orig - 2 * t_bar;
omega2_orig = 2 * delta * (t_bar - lambda2_orig);

temp_x = lam3_sim_one;
temp_y = ome_sim_one;
scatter(temp_x(A3&vol_sel==1),temp_y(A3&vol_sel==1), n_sim_one(A3&vol_sel==1),'blue') %change select-in color
hold on
scatter(temp_x(A3&vol_sel==0),temp_y(A3&vol_sel==0), n_sim_one(A3&vol_sel==0),'blue') %change select-out color
plot(lambda1_orig, omega1_orig, 'black');
plot(lambda2_orig, omega2_orig, '--black');
xlabel('$$\lambda_3$$', 'Interpreter', 'latex', 'FontSize', 15);
ylabel('\omega', 'FontSize', 15);
axis([1e4 4e4 0 3e3]) %crop the figure [x_min x_max y_min y_max]
txt1 = {'Selects BP','Inefficiently'};
txt2 = {'Selects BP','Efficiently'};
txt3 = {'Selects FFS'};
% txt4 = {'Selects FFS','Efficiently'};
text(1.2e4, 900, txt1, 'FontSize', 15, 'FontName','Times New Roman') %adjust "Select BP Inefficiently" position
text(1.8e4, 2300, txt2, 'FontSize', 15, 'FontName','Times New Roman') %adjust "Select BP Efficiently" position
text(3e4, 2000, txt3, 'FontSize', 15, 'FontName','Times New Roman') %adjust "Selects FFS" position
%text(2.5e4, 1800, txt4)
figdir = '';
%legend('Select-in','Select-out')
saveas(gcf,strcat(datapath, 'Figure4A'), 'png');
hold off


temp_x = (lam3_sim_one-tau_sim_one+t_bar);
temp_y = ome_sim_one;
scatter(temp_x(A3&vol_sel==1),temp_y(A3&vol_sel==1), n_sim_one(A3&vol_sel==1),'blue') %change select-in color
hold on
scatter(temp_x(A3&vol_sel==0),temp_y(A3&vol_sel==0), n_sim_one(A3&vol_sel==0),'blue') %change select-out color
plot(lambda1_orig, omega1_orig, 'black');
plot(lambda2_orig, omega2_orig, '--black');
xlabel('$$\lambda_3-b+\bar{b}$$', 'Interpreter', 'latex', 'FontSize', 15);
ylabel('\omega', 'FontSize', 15);
axis([1e4 4e4 0 3e3])%crop the figure [x_min x_max y_min y_max]
txt1 = {'Selects BP','Inefficiently'};
txt2 = {'Selects BP','Efficiently'};
txt3 = {'Selects FFS'};
% txt4 = {'Selects FFS','Efficiently'};
text(1.2e4, 900, txt1, 'FontSize', 15, 'FontName','Times New Roman') %adjust "Select BP Inefficiently" position
text(1.8e4, 2300, txt2, 'FontSize', 15, 'FontName','Times New Roman') %adjust "Select BP Efficiently" position
text(3e4, 2000, txt3, 'FontSize', 15, 'FontName','Times New Roman') %adjust "Selects FFS" position
%text(2.5e4, 1800, txt4)
figdir = '';
%legend('Select-in','Select-out')
saveas(gcf,strcat(datapath, 'Figure4B'), 'png');
hold off
