%% Table 4 Panel B

%functions for weighted mean, stddev, and correlation.
xx_wMean = @(x,w) sum(x.*w)./sum(w);
xx_wStdDev = @(x,w) sqrt(sum((x-xx_wMean(x,w)).^2.*w)./sum(w));
xx_wCorr = @(x,y,w) sum(w.*(x-xx_wMean(x,w)).*(y-xx_wMean(y,w)))./sum(w)./xx_wStdDev(x,w)./xx_wStdDev(y,w);

%a function that outputs [simple mean, simple StdDev]
CalcMeanStd = @(var) [mean(var),std(var)];

tb4_panelB = [CalcMeanStd(gamma1xx_S);...
              [0,0];%gamma 2, normalized to 0
              CalcMeanStd(gamma3xx_S);...
              CalcMeanStd(sig_eps_S);...
              CalcMeanStd(rho_S)];

 %% extract some point estimates
point_e = [CalcMeanStd(mu_lam_S); ...
              CalcMeanStd(sig_lam_S);...
              CalcMeanStd(gamma1xx_S);...
              CalcMeanStd(gamma3xx_S);...
              CalcMeanStd(sig_eps_S);...
              CalcMeanStd(mu_ome_S);...
              CalcMeanStd(sig_ome_S);...
              CalcMeanStd(rho_S);...
              CalcMeanStd(mu_u_S);...
              CalcMeanStd(sig_u_S)];
         
varlist = {'e_mu_lambda', 'e_sigma_lambda','e_gamma2','e_gamma3','e_sigma_epsilon','e_mu_omega','e_sigma_omega','e_rho','e_mu_u','e_sigma_u'}; 
for i = 1:length(varlist)
    eval(sprintf('%1$s = point_e(i,1);', varlist{i}));
end
%% Simulate epsilon_2 and epsilon_3
seed = 99;
rng(seed)
zeta_h = mvnrnd(0, 1, size(u_hS,1));
epsilon3_hS = zeta_h.*sig_eps_S;

rng(seed+1)
zeta_h_2 = mvnrnd(0, 1, size(u_hS,1));
epsilon2_hS = zeta_h_2.*sig_eps_S;
%% Table 5 Panel A
input = {lam_hS, ...
         ome_hS ...
         exp(lam_hS + gamma3xx_S + epsilon3_hS),...
         exp(ome_hS)};
tb5_panelA = xx_stackfun(input,all_n,'xx_calMSP');
%% Get Voluntary Group
raw_tau = rawData(:,6);
raw_selection = rawData(:,7);
raw_mandatory = rawData(:,8);
raw_n2 = rawData(:,5); %weight
raw_CJR = rawData(:,3);
raw_pre = rawData(:,2);
raw_y2 = rawData(:,1);
raw_strata = rawData(:,4);

clear '*_w'
clear 'vol*'
for cv = who('*_h*')' %transpose to get a row cell array
%   disp(cv{1})
  eval(sprintf('vol_%1$s = %1$s(raw_CJR==1 & raw_n2>0 & raw_mandatory==0,:);', cv{1})); %1$s is replaced by var name, output is named meanvarname
end

vol_sample = rawData(raw_CJR==1 & raw_n2>0 & raw_mandatory==0,:);
vol_n_h = vol_sample(:,5);
vol_tau_h = vol_sample(:,6);
vol_select_h = vol_sample(:,7);
vol_strata_h = vol_sample(:,4);

mean(xx_wCorr(vol_u_hS,vol_lam_hS,vol_n_h))  % rho_nu_lambda
mean(xx_wCorr(vol_u_hS,vol_ome_hS,vol_n_h))  % rho_nu_omega

%% Table 5 Panel B
input = {exp(vol_lam_hS), ...
         exp(vol_lam_hS + gamma3xx_S + vol_epsilon3_hS),...
         exp(vol_tau_h.*ones(size(vol_lam_hS))),...
         exp(vol_tau_h)-exp(vol_lam_hS + gamma3xx_S),...
         exp(vol_ome_hS),...
         exp(vol_tau_h)-exp(vol_lam_hS + gamma3xx_S)+exp(vol_ome_hS)./2,...
         vol_u_hS};
tb5_panelB = xx_stackfun(input,vol_n_h,'xx_calMSP');

%% Table 6 Panel A

%1.Medicare Cost; 2.Relative Social Cost; 3.Relative Hospital Profit; 4.
%Relative Social Surplus; 5.Relative Full Hospital Profit; 6. Relative Full
%Social Surplus 
LAM = 0.15;

selection_sim_hS = exp(vol_tau_h)-exp(vol_lam_hS + gamma3xx_S) + exp(vol_ome_hS)./2 + vol_u_hS > 0;
  
tb6_panelA = [xx_targeting(exp(vol_lam_hS + gamma3xx_S + vol_epsilon3_hS), selection_sim_hS.*0, exp(vol_ome_hS), vol_u_hS, exp(vol_tau_h), vol_n_h,LAM);...
                 xx_targeting(exp(vol_lam_hS + gamma3xx_S + vol_epsilon3_hS), selection_sim_hS.*0+1, exp(vol_ome_hS), vol_u_hS, exp(vol_tau_h), vol_n_h,LAM);...
                 xx_targeting(exp(vol_lam_hS + gamma3xx_S + vol_epsilon3_hS), selection_sim_hS, exp(vol_ome_hS), vol_u_hS, exp(vol_tau_h), vol_n_h,LAM)];
    
%% Estimation of tau parameters
v_n2 = vol_sample(:,5);
v_tau = vol_sample(:,6);
v_lam = vol_sample(:,2);

mu_tau = xx_wMean(v_tau,v_n2); %% This is the weighted mean of tau, using all voluntary hospitals.
mu_v_lam = xx_wMean(v_lam,v_n2); %%This is the weighted mean of period one level (lambda), using all voluntary hospitals.

sigma_tau = xx_wStdDev(v_tau,v_n2); %%This is the weighted SD of tau, using all voluntary hospitals. 
sigma_t_lam = xx_wStdDev(v_lam,v_n2); %%This is the weighted SD of period one level (lambda), using all voluntary hospitals.
v_cov_lam_tau = sum((v_tau - mu_tau).*(v_lam - mu_v_lam).*v_n2)/sum(v_n2); %%This is the weighted covariance_lambda_tau, using all voluntary hospitals. 
%% estimate rho_lam3_tau
v_lam3_hS = lam_hS(raw_CJR==1 & raw_n2>0 & raw_mandatory==0,:) + gamma3xx_S + epsilon3_hS(raw_CJR==1 & raw_n2>0 & raw_mandatory==0,:);
%% Table 4 Panel B
mu_tau_specs = xx_wMean(v_lam3_hS,v_n2);
sigma_tau_specs = {xx_wStdDev(v_lam3_hS,v_n2), xx_wStdDev(lam_hS(raw_CJR==1 & raw_n2>0 & raw_mandatory==0,:),v_n2), sigma_tau, 0, 0.09, 0.15};%
rho_lam3_tau_specs = {1, xx_wStdDev(lam_hS(raw_CJR==1 & raw_n2>0 & raw_mandatory==0,:),v_n2)./xx_wStdDev(v_lam3_hS,v_n2), v_cov_lam_tau./(sigma_tau.*xx_wStdDev(v_lam3_hS,v_n2)), 0, 0.76, 0.87}; %

% tb_spec_sumbers = [mu_tau_specs',sigma_tau_specs',rho_lam3_tau_specs'];

rng(seed+1)
epsilon_tau_h = normrnd(0,1,[size(vol_lam_hS,1),1]);

tb6_panelB_pt1 = [];
tb3_spec1 = [];

for i=1:6
    disp(i)
    tb3_spec1 = [tb3_spec1;mean(mu_tau_specs), mean(sigma_tau_specs{i}), mean(rho_lam3_tau_specs{i})];
    mu_tau_tmp_hS = mu_tau_specs + rho_lam3_tau_specs{i}.*sigma_tau_specs{i}./xx_wStdDev(v_lam3_hS,v_n2).*((vol_lam_hS+gamma3xx_S+vol_epsilon3_hS) - xx_wMean(v_lam3_hS,v_n2));
    sigma_tau_tmp = sqrt(1-rho_lam3_tau_specs{i}.^2).*sigma_tau_specs{i};
%     disp(sigma_tau_tmp)

    tau_tmp_hS = mu_tau_tmp_hS + sigma_tau_tmp.*epsilon_tau_h;
    
    selection_sim_hS = exp(tau_tmp_hS)-exp(vol_lam_hS + gamma3xx_S) + exp(vol_ome_hS)./2 + vol_u_hS > 0 ;
                
    tmp_tb4_panelB = xx_targeting(exp(vol_lam_hS + gamma3xx_S + vol_epsilon3_hS), selection_sim_hS, exp(vol_ome_hS), vol_u_hS, exp(tau_tmp_hS), vol_n_h,LAM);
    
    tb6_panelB_pt1 = [tb6_panelB_pt1;...
                    tmp_tb4_panelB];
end
%% 
mu_tau_specs = mu_tau;
sigma_tau_specs = {xx_wStdDev(v_lam3_hS,v_n2), xx_wStdDev(lam_hS(raw_CJR==1 & raw_n2>0 & raw_mandatory==0,:),v_n2),sigma_tau,0,0.09,sigma_tau};
tb6_panelB_pt2 = [];
tb3_spec2 = [];
for i=1:6
    disp(i)
    tb3_spec2 = [tb3_spec2;mean(mu_tau_specs), mean(sigma_tau_specs{i}), mean(rho_lam3_tau_specs{i})];
    mu_tau_tmp_hS = mu_tau_specs + rho_lam3_tau_specs{i}.*sigma_tau_specs{i}./xx_wStdDev(v_lam3_hS,v_n2).*((vol_lam_hS+gamma3xx_S+vol_epsilon3_hS) - xx_wMean(v_lam3_hS,v_n2));
    sigma_tau_tmp = sqrt(1-rho_lam3_tau_specs{i}.^2).*sigma_tau_specs{i};
%     disp(sigma_tau_tmp)

    tau_tmp_hS = mu_tau_tmp_hS + sigma_tau_tmp.*epsilon_tau_h;
    
    selection_sim_hS = exp(tau_tmp_hS)-exp(vol_lam_hS + gamma3xx_S) + exp(vol_ome_hS)./2 + vol_u_hS > 0 ;
                
    tmp_tb4_panelB = xx_targeting(exp(vol_lam_hS + gamma3xx_S + vol_epsilon3_hS), selection_sim_hS, exp(vol_ome_hS), vol_u_hS, exp(tau_tmp_hS), vol_n_h,LAM);
    
    tb6_panelB_pt2 = [tb6_panelB_pt2;...
                    tmp_tb4_panelB];
end
tb6_panelB = [tb6_panelB_pt1(1:2,:);tb6_panelB_pt2(3:5,:)];

