clear;clc;close all
rng(2021)
% addpath('../lib')

output_path = './output/';
data_path = './input/model_input_mcmc_new.xlsx';
chars_path = './input/hosp_char_mcmc.xlsx';

%% Preliminary
% Load data
T = readtable(data_path);
x = readtable(chars_path);
T = join(T, x, 'Keys', 'provider');
H = size(T, 1);
% Treatement, selection, outcome
lny1 = T.logy1;
y2 = exp(T.logy2);
y3 = exp(T.logy3);
BP2 = T.CJR;
mandatory = T.mandatory & BP2 == 1;
t = exp(T.log_tau);
t(BP2 == 0 | mandatory == 1) = 0;
BP3 = T.selection;
selection = BP3 == 1 & mandatory == 0;
H1 = find(BP2 == 0);
H2 = find(BP2 == 1 & mandatory == 1);
H3 = find(BP2 == 1 & mandatory == 0 & selection == 1);
H4 = find(BP2 == 1 & mandatory == 0 & selection == 0);
H234 = [H2; H3; H4];
H23 = [H2; H3];
H12 = [H1; H2];
H34 = [H3; H4];
% Weights
weights = T.num_epsd;
weights = weights / sum(weights) * H;
w = diag(weights(H34) / sum(weights(H34)) * length(H34));
% Characteristics
types = [T.prov_coth, T.prov_fp, T.prov_govt];
bin = [T.prov_gtmedepsds, T.prov_gtmedbeds, T.prov_cqs_abovemed];
cnt = [log(T.num_epsd_pre_T), log(T.prov_beds), T.cqs];
chars_raw = [types, cnt];
chars = (chars_raw - wmean(chars_raw, repmat(weights, 1, size(chars_raw, 2)))) ./ sqrt(var(chars_raw, weights));
strata = T.strata;
strata_unique = unique(strata);
strata_FEs = zeros(H, length(strata_unique) - 1);
for i = 1:length(strata_unique)
    strata_FEs(:, i) = strata == strata_unique(i);
end
X1 = [strata_FEs, chars];
X2 = [strata_FEs, chars];
X3 = [strata_FEs, chars];
X3(:, [4, 8]) = [];

% Containers
S = 100000;
% Parameters
alpha1_iter = zeros(size(X1, 2), S);
alpha2_iter = zeros(size(X2, 2), S);
alpha3_iter = zeros(size(X3, 2), S);
sigma_lambda_iter = zeros(1, S);
sigma_omega_iter = zeros(1, S);
rho_iter = zeros(1, S);
tau_e_iter = zeros(1, S);
beta1_iter = zeros(1, S);
gamma1_iter = zeros(1, S);
gamma3_iter = zeros(1, S);
% Nuisance parameters
lnlambda_iter = zeros(H, S);
lnomega_iter = zeros(H, S);
u_iter = zeros(H, S);

% Initial guess
gamma1_iter(1) = wmean(lny1(H1) - log(y2(H1)), weights(H1));
gamma3_iter(1) = wmean(log(y3(H1)) - log(y2(H1)), weights(H1));
sigma_e = sqrt(var([lny1(H1) - gamma1_iter(1) - log(y2(H1)); ...
    log(y3(H1)) - gamma3_iter(1) - log(y2(H1))], [weights(H1); weights(H1)]) / 2);
tau_e_iter(1) = 1 / sigma_e^2;
alpha1_iter(:, 1) = regress(lny1 - gamma1_iter(1), X1);
sigma_lambda_iter(1) = sqrt(var(lny1 - gamma1_iter(1), weights) - sigma_e^2);

diff = exp(lny1 - gamma1_iter(1) + sigma_e^2) - y2;
ind = diff > 0 & BP2 == 1;
alpha2_iter(:, 1) = regress(log(diff(ind)), X2(ind, :));
sigma_omega_iter(1) = sqrt(var(log(diff(ind)), weights(ind)));
rho_iter(1) = corr(lny1(ind), log(diff(ind)));
lnlambda_iter(:, 1) = lny1 - gamma1_iter(1);
mu_cond = X2 * alpha2_iter(:, 1) + rho_iter(1) * sigma_omega_iter(1) / sigma_lambda_iter(1) * (lnlambda_iter(:, 1) - X1 * alpha1_iter(:, 1));
sigma_cond = sqrt(1 - rho_iter(1)^2) * sigma_omega_iter(1);
lnomega_iter(:, 1) = mu_cond + randn(H, 1) * sigma_cond;

alpha3_iter(:, 1) = zeros(size(X3, 2), 1);
beta1_iter(1) = 0.0002;

cutoff = - X3 * alpha3_iter(:, 1) - beta1_iter(1) * (t + exp(lnomega_iter(:, 1)) / 2 - exp(lnlambda_iter(:, 1))); % indifferent between BP and FFS
u_iter(H12, 1) = randn(size(H12));
for hh = 1:length(H34)
    h = H34(hh);
    if BP3(h) == 1
        u_iter(h, 1) = trandn(cutoff(h), Inf);
    else
        u_iter(h, 1) = trandn(-Inf, cutoff(h));
    end
end

%% Gibbs sampling
for s = 2:S
    disp(s)
    alpha1 = alpha1_iter(:, s - 1);
    sigma_lambda = sigma_lambda_iter(s - 1);
    alpha2 = alpha2_iter(:, s - 1);
    sigma_omega = sigma_omega_iter(s - 1);
    rho = rho_iter(s - 1);
    tau_e = tau_e_iter(s - 1);
    sigma_e = 1 / sqrt(tau_e);
    alpha3 = alpha3_iter(:, s - 1);
    beta1 = beta1_iter(s - 1);
    gamma1 = gamma1_iter(s - 1);
    gamma3 = gamma3_iter(s - 1);
    lnomega = lnomega_iter(:, s - 1);
    lnlambda = lnlambda_iter(:, s - 1);
    u = u_iter(:, s - 1);
    fprintf("%4.3f, %4.3f, %4.3f, %4.3f, %4.3f, %4.3f, %4.3f, %6.5f, %4.3f, %4.3f\n", ...
        wmean(X1 * alpha1, weights), sigma_lambda, wmean(X2 * alpha2, weights), sigma_omega, ...
        rho, sigma_e, wmean(X3(H34, :) * alpha3, weights(H34)), beta1, gamma1, gamma3);
    
    % u
    % H12: control group: normal distribution
    u_iter(H12, s) = randn(size(H12));
    % H34: voluntary treated, truncation consistent with self-selection
    cutoff = - X3 * alpha3 - beta1 * (t + exp(lnomega) / 2 - exp(lnlambda + gamma3)); % indifferent between BP and FFS
    for hh = 1:length(H34)
        h = H34(hh);
        if BP3(h) == 1
            u_iter(h, s) = trandn(cutoff(h), Inf);
        else
            u_iter(h, s) = trandn(-Inf, cutoff(h));
        end
    end
    u = u_iter(:, s);
    
    % ln(omega)
    mu_cond = X2 * alpha2 + rho * sigma_omega / sigma_lambda * (lnlambda - X1 * alpha1);
    sigma_cond = sqrt(1 - rho^2) * sigma_omega;
    % H1: control
    control = mu_cond(H1) + randn(size(H1)) * sigma_cond;
    lnomega_iter(H1, s) = min([control, log(0.71) + lnlambda(H1)], [], 2); % Truncation;
    % H234: treated
    cutoff = 2 * (exp(lnlambda + gamma3) - t - (u + X3 * alpha3) / beta1); % indifferent between BP and FFS
    sim_upper = 0.71 * exp(lnlambda);
    sim_lower = 1;
    for hh = 1:length(H234)
        h = H234(hh);
        if mandatory(h) == 1 % H2: mandatory, no self-selection, no truncation
            int_upper_h = Inf;
            int_lower_h = 0;
        elseif BP3(h) == 1 % H34: voluntary, truncation consistent with self-selection
            int_upper_h = Inf;
            int_lower_h = max(cutoff(h), 0);
        else
            int_upper_h = cutoff(h);
            int_lower_h = 0;
        end
        sim_upper_h = min([sim_upper(h), int_upper_h]);
        sim_lower_h = max([sim_lower, int_lower_h]);
        f = @(omega) g(omega, mu_cond(h), lnlambda(h), lnlambda(h) + gamma3, sigma_cond^2, sigma_e^2, y2(h), y3(h), BP2(h), BP3(h), 1);
        normalization = integral(f, int_lower_h, int_upper_h);
        f = @(omega) g(omega, mu_cond(h), lnlambda(h), lnlambda(h) + gamma3, sigma_cond^2, sigma_e^2, y2(h), y3(h), BP2(h), BP3(h), normalization);
        p = rand();
        F = @(omega) integral(f, int_lower_h, omega) - p;
        if F(sim_upper_h) <= 0
            lnomega_iter(h, s) = log(sim_upper_h);
        elseif F(sim_lower_h) >= 0
            lnomega_iter(h, s) = log(sim_lower_h);
        else
            lnomega_iter(h, s) = log(fzero(F, [sim_lower_h, sim_upper_h]));
        end
    end
    lnomega = lnomega_iter(:, s);
    
    % ln(lambda)
    mu = X1 * alpha1 + rho * sigma_lambda / sigma_omega * (lnomega - X2 * alpha2);
    ss = (1 - rho^2) * sigma_lambda^2;
    Sigma12 = [ss, ss, ss];
    Sigma21 = Sigma12';
    Sigma22 = [ss + sigma_e^2, ss, ss; ss, ss + sigma_e^2, ss; ss, ss, ss + sigma_e^2];
    aa = Sigma12 / Sigma22;
    bb = aa * Sigma21;
    mu_cond = mu + [lny1 - mu - gamma1, log(y2 + BP2 .* exp(lnomega)) - mu, log(y3 + BP3 .* exp(lnomega)) - mu - gamma3] * aa';
    sigma_cond = sqrt(ss - bb);
    % H12: control + mandatory treated
    lnlambda_iter(H12, s) = mu_cond(H12) + randn(size(H12)) * sigma_cond;
    % H34: voluntary treated, truncation consistent with self-selection
    cutoff = log(max(0, t + exp(lnomega) / 2 + (u + X3 * alpha3) / beta1)) - gamma3; % indifferent between BP and FFS
    for hh = 1:length(H34)
        h = H34(hh);
        if BP3(h) == 1
            lnlambda_iter(h, s) = mu_cond(h) + trandn(-Inf, (cutoff(h) - mu_cond(h)) / sigma_cond) * sigma_cond;
        else
            lnlambda_iter(h, s) = mu_cond(h) + trandn((cutoff(h) - mu_cond(h)) / sigma_cond, Inf) * sigma_cond;
        end
    end
    lnlambda = lnlambda_iter(:, s);
    x = [X3, t + exp(lnomega) / 2 - exp(lnlambda + gamma3)];
    z = x * [alpha3; beta1] + u;
    x = x(H34, :);
    z = z(H34);
    
    % gamma1
    gamma1_iter(s) = wmean(lny1 - lnlambda, weights) + randn(1) / sqrt(tau_e * H);
    gamma1 = gamma1_iter(s);
    
    % gamma3
    gamma3_iter(s) = wmean(log(y3 + BP3 .* exp(lnomega)) - lnlambda, weights) + randn(1) / sqrt(tau_e * H);
    gamma3 = gamma3_iter(s);
    
    % alpha
    X = [X1, zeros(H, size(X2, 2)); zeros(H, size(X1, 2)), X2];
    y = [lnlambda; lnomega];
    Omega = [eye(H) * sigma_lambda^2, ...
        eye(H) * rho * sigma_lambda * sigma_omega; ...
        eye(H) * rho * sigma_lambda * sigma_omega, ...
        eye(H) * sigma_omega^2];
    W = diag([weights; weights]);
    invOmega = inv(Omega);
    temp = inv(X' * invOmega * W * X);
    [~, err] = cholcov(temp);
    if err == 0
        invAlpha = temp;
    else
        for d = [14, 13, 12, 11, 10, 9, 8]
            temp_rounded = round(temp, d);
            [~, err] = cholcov(temp_rounded);
            if err == 0
                invAlpha = temp_rounded;
                continue
            end
        end
    end
    if err ~= 0
        save(sprintf('%s/est_x_NPSDalpha%d', output_path, s), 'sigma_lambda', 'sigma_omega', 'rho', 'X', 'W', 'weights')
    end
    temp = mvnrnd(invAlpha * X' * invOmega * W * y, invAlpha);
    alpha1_iter(:, s) = temp(1:size(X1, 2));
    alpha2_iter(:, s) = temp((size(X1, 2) + 1):end);
    alpha1 = alpha1_iter(:, s);
    alpha2 = alpha2_iter(:, s);
    
    % Sigma
    nu = H;
    ep = sqrt(weights) .* [lnlambda - X1 * alpha1, lnomega - X2 * alpha2];
    Sn = ep' * ep;
    temp = iwishrnd(Sn, nu);
    sigma_lambda_iter(s) = sqrt(temp(1));
    sigma_omega_iter(s) = sqrt(temp(4));
    rho_iter(s) = temp(2) / sqrt(temp(1)) / sqrt(temp(4));
    sigma_lambda = sigma_lambda_iter(s);
    sigma_omega = sigma_omega_iter(s);
    rho = rho_iter(s);
    
    % beta
    temp = inv(x' * w * x);
    [~, err] = cholcov(temp);
    if err == 0
        invBeta = temp;
    else
        for d = [14, 13, 12, 11, 10, 9, 8]
            temp_rounded = round(temp, d);
            [~, err] = cholcov(temp_rounded);
            if err == 0
                invBeta = temp_rounded;
                continue
            end
        end
    end
    if err ~= 0
        save(sprintf('%s/est_x_NPSDbeta%d', output_path, s), 'x', 'w')
    end
    temp = mvnrnd(invBeta * x' * w * z, invBeta);
    alpha3_iter(:, s) = temp(1:(end - 1));
    beta1_iter(s) = max(temp(end), 0.00001);
    alpha3 = alpha3_iter(:, s);
    beta1 = beta1_iter(s);
    
    % tau_e
    a = H * 3 / 2;
    b = sum(weights .* (lny1 - lnlambda - gamma1).^2) / 2 + ...
        sum(weights .* (log(y2 + BP2 .* exp(lnomega)) - lnlambda).^2) / 2 + ...
        sum(weights .* (log(y3 + BP3 .* exp(lnomega)) - lnlambda - gamma3).^2) / 2;
    tau_e_iter(s) = gamrnd(a, 1 / b);
    tau_e = tau_e_iter(s);
    sigma_e = 1 / sqrt(tau_e);
    
    if mod(s, 2500) == 0
        lnlambda_finish     = lnlambda_iter(:, 1:s);
        lnomega_finish      = lnomega_iter(:, 1:s);
        u_finish            = u_iter(:, 1:s);
        alpha1_finish       = alpha1_iter(:, 1:s);
        alpha2_finish       = alpha2_iter(:, 1:s);
        alpha3_finish       = alpha3_iter(:, 1:s);
        sigma_lambda_finish = sigma_lambda_iter(1:s);
        sigma_omega_finish  = sigma_omega_iter(1:s);
        rho_finish          = rho_iter(1:s);
        tau_e_finish        = tau_e_iter(1:s);
        beta1_finish        = beta1_iter(1:s);
        gamma1_finish       = gamma1_iter(1:s);
        gamma3_finish       = gamma3_iter(1:s);
        save(sprintf('%s/ests_x', output_path), 'lnlambda_finish', 'lnomega_finish', 'u_finish', ...
            'alpha1_finish', 'alpha2_finish', 'alpha3_finish', ...
            'sigma_lambda_finish', 'sigma_omega_finish', 'rho_finish', ...
            'tau_e_finish', 'beta1_finish', 'gamma1_finish', 'gamma3_finish', ...
            'weights', 'X1', 'X2', 'X3', 'chars_raw', 'H34', 'H234')
    end
end
