
*********************;
*LIBRARY AND OPTIONS*;
*********************;

options pagesize=200;
options nocenter;
options mprint mlogic;
options errorabend;
options errorbyabend;
options errorcheck = strict;
options msglevel=i;
options notes stimer fullstimer;
options formdlim="-";
options mergenoby=error;
options filelocks=none;
options syntaxcheck;
options vnferr;
options varinitchk = error;
options varlenchk = nowarn;

libname mc '[DATA DIR]';
libname temp '[TEMP DIR]';
libname output '[OUTPUT DIR]';

%let numobs = MAX;

****************;
*LOAD CSV FILES*;
****************;

%macro importcsv(filename);
proc import datafile="[INPUT DIR]/&filename..csv"
	out=temp.&filename. dbms=csv replace; 
	getnames=yes; 
	GUESSINGROWS=MAX;
run;
%mend;
%importcsv(drg_gmlos2015);
%importcsv(ip_readmission_exclusions);
%importcsv(provider_to_msa_xwalk2016);
%importcsv(ptb_excluded_icd10);
%importcsv(ssacounty_to_msa_xwalk);
%importcsv(treatment_eligible_strata);
%importcsv(hip_fracture_icd10);
%importcsv(bpci_hosps_2016_2018);
data temp.ip_readmission_exclusions (rename = (drg = drg_cd));
	set temp.ip_readmission_exclusions;
	drg = put(drg_cd, 3.);
	drop drg_cd;
run;


********************;
*BUILD EPISODE DATA*;
********************;

***************;
*LOAD BSF DATA*;
***************;

data temp.denom2016;
	set mc.denom2016;
	year = 2016;
	rename entitl1 = buyin12016;
	rename entitl2 = buyin22016;
	rename entitl3 = buyin32016;
	rename entitl4 = buyin42016;
	rename entitl5 = buyin52016;
	rename entitl6 = buyin62016;
	rename entitl7 = buyin72016;
	rename entitl8 = buyin82016;
	rename entitl9 = buyin92016;
	rename entitl10 = buyin102016;
	rename entitl11 = buyin112016;
	rename entitl12 = buyin122016;
	rename hmo1 = hmo12016;
	rename hmo2 = hmo22016;
	rename hmo3 = hmo32016;
	rename hmo4 = hmo42016;
	rename hmo5 = hmo52016;
	rename hmo6 = hmo62016;
	rename hmo7 = hmo72016;
	rename hmo8 = hmo82016;
	rename hmo9 = hmo92016;
	rename hmo10 = hmo102016;
	rename hmo11 = hmo112016;
	rename hmo12 = hmo122016;
run;

data temp.denom2017;
	set mc.denom2017;
	year = 2017;
	rename entitl1 = buyin12017;
	rename entitl2 = buyin22017;
	rename entitl3 = buyin32017;
	rename entitl4 = buyin42017;
	rename entitl5 = buyin52017;
	rename entitl6 = buyin62017;
	rename entitl7 = buyin72017;
	rename entitl8 = buyin82017;
	rename entitl9 = buyin92017;
	rename entitl10 = buyin102017;
	rename entitl11 = buyin112017;
	rename entitl12 = buyin122017;
	rename hmo1 = hmo12017;
	rename hmo2 = hmo22017;
	rename hmo3 = hmo32017;
	rename hmo4 = hmo42017;
	rename hmo5 = hmo52017;
	rename hmo6 = hmo62017;
	rename hmo7 = hmo72017;
	rename hmo8 = hmo82017;
	rename hmo9 = hmo92017;
	rename hmo10 = hmo102017;
	rename hmo11 = hmo112017;
	rename hmo12 = hmo122017;
run;

data temp.denom2018;
	set mc.denom2018;
	year = 2018;
	rename entitl1 = buyin12018;
	rename entitl2 = buyin22018;
	rename entitl3 = buyin32018;
	rename entitl4 = buyin42018;
	rename entitl5 = buyin52018;
	rename entitl6 = buyin62018;
	rename entitl7 = buyin72018;
	rename entitl8 = buyin82018;
	rename entitl9 = buyin92018;
	rename entitl10 = buyin102018;
	rename entitl11 = buyin112018;
	rename entitl12 = buyin122018;
	rename hmo1 = hmo12018;
	rename hmo2 = hmo22018;
	rename hmo3 = hmo32018;
	rename hmo4 = hmo42018;
	rename hmo5 = hmo52018;
	rename hmo6 = hmo62018;
	rename hmo7 = hmo72018;
	rename hmo8 = hmo82018;
	rename hmo9 = hmo92018;
	rename hmo10 = hmo102018;
	rename hmo11 = hmo112018;
	rename hmo12 = hmo122018;
run;

data temp.bsf_loaded2016_2018
	(keep = bene_: msc: year);
	set temp.denom2016
	temp.denom2017
	temp.denom2018;
	rename sdod = bene_death_dt;
	rename sdob = bene_dob;
	rename sex = bene_sex;
	rename race = bene_race;
	rename age = bene_age;
	rename county = bene_cnty_cd;
	rename state = bene_state_cd;
	rename oentitl = bene_orec;
	rename centitl = bene_crec;
	rename stbuyin = buyin_mo;
	rename hmocov = hmo_mo;
run;

proc sql nowarn;
	 create table tempfile as 
	 select A.*, B.*
	 from temp.denom2017 as A
	 full join 
	 temp.denom2016 as B
	 on A.bene_id = B.bene_id;
quit;

proc sql nowarn;
	 create table tempfile2 as 
	 select A.*, B.*
	 from tempfile as A
	 full join 
	 temp.denom2018 as B
	 on A.bene_id = B.bene_id;
quit;

data temp.bsf_elig2016_2018
	(keep = bene_id buyin: hmo:);
	set tempfile2;
run;

**************************;
*LOAD ALL LEJR ADMISSIONS*;
**************************;
data temp.ip2016clm;
	set mc.ip2016clm;
	year = 2016;
run;

data temp.ip2017clm;
	set mc.ip2017clm;
	year = 2017;
run;

data temp.ip2018clm;
	set mc.ip2018clm;
	year = 2018;
run;

data tempfile(keep = admsn_dt dschrgdt pmt_amt util_day per_diem
	ded_amt coin_amt icd_cd blddedam pdgns_cd bene_id
	drg_cd pps_ind provider stus_cd prpay_cd oop_amt year dsh_op);
	set temp.ip2016clm(rename = (sadmsndt = admsn_dt sdschrgdt = dschrgdt))
	temp.ip2017clm(rename = (sadmsndt = admsn_dt sdschrgdt = dschrgdt))
	temp.ip2018clm(rename = (sadmsndt = admsn_dt sdschrgdt = dschrgdt));
	pmt_amt = pmt_amt + util_day*per_diem ;
	if pmt_amt < 0 then pmt_amt = 0 ;
	oop_amt = ded_amt + coin_amt + blddedam ;
	if dsh_op < 0 then dsh_op = 0;
	icd_cd = pdgns_cd;
run;

proc sort data = tempfile out=tempfile;
	by icd_cd;
quit;

data temp.hip_fracture_icd_loaded (keep = icd_cd hip_fracture_clm);
	set temp.hip_fracture_icd10;
	icd_cd = compress(icd10_cd,".");
	hip_fracture_clm = 1;
run;

proc sort data = temp.hip_fracture_icd_loaded out=temp.hip_fracture_icd_loaded;
	by icd_cd;
quit;

proc sql nowarn;
	create table tempfile2 as
	select A.*, B.*
	from tempfile as A
	left join
	temp.hip_fracture_icd_loaded as B
	on A.icd_cd=B.icd_cd;
quit;
		
proc sort data = tempfile2 out = tempfile3;
	by bene_id year admsn_dt provider dschrgdt;
quit;

data temp.ip_stay_level_loaded2016_2018 
	(keep = ipf ach ltch irf bene_id admsn_dt dschrgdt provider prvdrnum payment oop
        stus_cd mcareprimary pps_ind drg_cd hip_fracture_flag year dsh_pay); 
	
	set tempfile3;
	by bene_id year admsn_dt provider dschrgdt;
	retain payment oop mcareprimary hip_fracture_flag dsh_op;
	
	mcareprimary_clm = (prpay_cd in ("", "Z"));
	
	if first.provider then do;
		payment = pmt_amt;
		oop = oop_amt; 
		mcareprimary = mcareprimary_clm ;
		hip_fracture_flag = hip_fracture_clm;
		dsh_pay = dsh_op;
	end;
	
	else do;
		payment = payment + pmt_amt;
		oop = oop + oop_amt;
		if mcareprimary_clm < mcareprimary then mcareprimary = mcareprimary_clm;
		if hip_fracture_flag < hip_fracture_clm then hip_fracture_flag = 1;
		dsh_pay = dsh_pay + dsh_op;
	end;
	
	
	if last.provider;
	
	prvdstr = substr(provider, 3, 4);

	* only keep those with only numeric values in the last four digits; 

	if anyalpha(prvdstr) = 0 ; 
	prvdrnum = input(prvdstr, 4.);

	ach  = ((prvdrnum <= 999 & ~missing(prvdrnum)) | (prvdrnum >= 1300 & prvdrnum <= 1399)) ;
	ltch = (prvdrnum <= 2299 & prvdrnum >= 2000) ;
	irf  = (prvdrnum <= 3099 & prvdrnum >= 3025) ;
	ipf  = (prvdrnum <= 4499 & prvdrnum >= 4000) ;
	
	if ~missing(dschrgdt) and stus_cd ~= "30";
	if missing(hip_fracture_flag) then hip_fracture_flag = 0;
run;

data tempfile;
	set temp.ip_stay_level_loaded2016_2018 (where = (ach = 1 and (drg_cd = "469" or drg_cd = "470"))
	rename = (payment = index_pay oop = index_oop));
	format apr12016 date9.;
	format sep152018 date9.;
	apr12016 = input("01APR2016",date9.);
	sep152018 = input("15SEP2018",date9.);
	if admsn_dt <= sep152018 and admsn_dt >= apr12016;
	los = max(dschrgdt - admsn_dt, 1);
	epsdenddt = dschrgdt + 89;

run;

proc sql nowarn;
	 create table tempfile as 
	 select A.*, B.*
	 from tempfile as A
	 inner join 
	 temp.bsf_loaded2016_2018 as B
	 on A.bene_id = B.bene_id and A.year = B.year;
quit;

proc sql nowarn;
	create table temp.all_lejr_index2016_2018 as 
	 select A.*, B.*
	 from tempfile as A
	 left join 
	 temp.bsf_elig2016_2018 as B
	 on A.bene_id = B.bene_id;
quit;


**********************************;
*DEFINE CJR LEJR INDEX ADMISSIONS*;
**********************************;

data tempfile;
	set temp.bpci_hosps_2016_2018(rename = (provider = provider_num));
	provider = put(provider_num, z6.);
run;

proc sql nowarn;
	create table tempinput_merge as
	select A.*, B.*
	from temp.all_lejr_index2016_2018 as A
	left join
	tempfile as B
	on A.provider = B.provider;
quit;

data temp.tempinput;
	set tempinput_merge;

	drop_pps = (pps_ind ~="2");

	jan12016 = input("01JAN2016",date9.);
	july12016 = input("01JUL2016",date9.);
	oct12016 = input("01OCT2016",date9.);
	jan12017 = input("01JAN2017",date9.);
	apr12017 = input("01APR2017",date9.);
	july12017 = input("01JUL2017",date9.);
	oct12017 = input("01OCT2017",date9.);
	jan12018 = input("01JAN2018",date9.);
	apr12018 = input("01APR2018",date9.);
	july12018 = input("01JUL2018",date9.);
	oct12018 = input("01OCT2018",date9.);
	jan12019 = input("01JAN2019",date9.);

	episode_quarter12016 = (admsn_dt < apr12016 & epsdenddt >= jan12016);
	episode_quarter12017 = (admsn_dt < apr12017 & epsdenddt >= jan12017);	
	episode_quarter12018 = (admsn_dt < apr12018 & epsdenddt >= jan12018);	
        episode_quarter22016 = (admsn_dt < july12016 & epsdenddt >= apr12016);
	episode_quarter22017 = (admsn_dt < july12017 & epsdenddt >= apr12017);
	episode_quarter22018 = (admsn_dt < july12018 & epsdenddt >= apr12018);
        episode_quarter32016 = (admsn_dt < oct12016 & epsdenddt >= july12016);
	episode_quarter32017 = (admsn_dt < oct12017 & epsdenddt >= july12017);
	episode_quarter32018 = (admsn_dt < oct12018 & epsdenddt >= july12018);
        episode_quarter42016 = (admsn_dt < jan12017 & epsdenddt >= oct12016);
	episode_quarter42017 = (admsn_dt < jan12018 & epsdenddt >= oct12017);
	episode_quarter42018 = (admsn_dt < jan12019 & epsdenddt >= oct12018);

        drop_bpci = 0;

	if episode_quarter12016 = 1 & bpci_quarter12016 = 1 then drop_bpci = 1;
	if episode_quarter22016 = 1 & bpci_quarter22016 = 1 then drop_bpci = 1;
	if episode_quarter32016 = 1 & bpci_quarter32016 = 1 then drop_bpci = 1;
	if episode_quarter42016 = 1 & bpci_quarter42016 = 1 then drop_bpci = 1;
	if episode_quarter12017 = 1 & bpci_quarter12017 = 1 then drop_bpci = 1;
	if episode_quarter22017 = 1 & bpci_quarter22017 = 1 then drop_bpci = 1;
	if episode_quarter32017 = 1 & bpci_quarter32017 = 1 then drop_bpci = 1;
	if episode_quarter42017 = 1 & bpci_quarter42017 = 1 then drop_bpci = 1;
	if episode_quarter12018 = 1 & bpci_quarter12018 = 1 then drop_bpci = 1;
	if episode_quarter22018 = 1 & bpci_quarter22018 = 1 then drop_bpci = 1;
	if episode_quarter32018 = 1 & bpci_quarter32018 = 1 then drop_bpci = 1;
	* There is no bpci q4 2018 (bpci ended and it is beyond our sample);
run;

data tempfile;
	set temp.tempinput;
	
	episode_mo042016 =  ((month(admsn_dt) <= 04 & month(epsdenddt) >= 04 & year(admsn_dt) = 2016) | 
			(year(admsn_dt) = 2016 & month(admsn_dt) <= 04 & year(epsdenddt) = 2017));
	episode_mo052016 =  ((month(admsn_dt) <= 05 & month(epsdenddt) >= 05 & year(admsn_dt) = 2016) | 
			(year(admsn_dt) = 2016 & month(admsn_dt) <= 05 & year(epsdenddt) = 2017));
	episode_mo062016 =  ((month(admsn_dt) <= 06 & month(epsdenddt) >= 06 & year(admsn_dt) = 2016) |
			(year(admsn_dt) = 2016 & month(admsn_dt) <= 06 & year(epsdenddt) = 2017));
	episode_mo072016 =  ((month(admsn_dt) <= 07 & month(epsdenddt) >= 07 & year(admsn_dt) = 2016) |
			(year(admsn_dt) = 2016 & month(admsn_dt) <= 07 & year(epsdenddt) = 2017));
	episode_mo082016 =  ((month(admsn_dt) <= 08 & month(epsdenddt) >= 08 & year(admsn_dt) = 2016) |
			(year(admsn_dt) = 2016 & month(admsn_dt) <= 08 & year(epsdenddt) = 2017));
	episode_mo092016 =  ((month(admsn_dt) <= 09 & month(epsdenddt) >= 09 & year(admsn_dt) = 2016) |
			(year(admsn_dt) = 2016 & month(admsn_dt) <= 09 & year(epsdenddt) = 2017));
	episode_mo102016 =  ((month(admsn_dt) <= 10 & month(epsdenddt) >= 10 & year(admsn_dt) = 2016) |
			(year(admsn_dt) = 2016 & month(admsn_dt) <= 10 & year(epsdenddt) = 2017));
	episode_mo112016 =  ((month(admsn_dt) <= 11 & month(epsdenddt) >= 11 & year(admsn_dt) = 2016) |
			(year(admsn_dt) = 2016 & month(admsn_dt) <= 11 & year(epsdenddt) = 2017));
	episode_mo122016 =  ((month(admsn_dt) <= 12 & month(epsdenddt) >= 12 & year(admsn_dt) = 2016) |
			(year(admsn_dt) = 2016 & month(admsn_dt) <= 12 & year(epsdenddt) = 2017));


	episode_mo012017 =  ((month(admsn_dt) <= 01 & month(epsdenddt) >= 01 & year(epsdenddt) = 2017) | 
			(year(admsn_dt) = 2016 & month(epsdenddt) >= 01 & year(epsdenddt) = 2017));
	episode_mo022017 =  ((month(admsn_dt) <= 02 & month(epsdenddt) >= 02 & year(epsdenddt) = 2017) | 
			(year(admsn_dt) = 2016 & month(epsdenddt) >= 02 & year(epsdenddt) = 2017));
	episode_mo032017 =  ((month(admsn_dt) <= 03 & month(epsdenddt) >= 03 & year(epsdenddt) = 2017) |
			(year(admsn_dt) = 2016 & month(epsdenddt) >= 03 & year(epsdenddt) = 2017));
	episode_mo042017 =  ((month(admsn_dt) <= 04 & month(epsdenddt) >= 04 & year(epsdenddt) = 2017) | 
			(year(admsn_dt) = 2016 & month(epsdenddt) >= 04 & year(epsdenddt) = 2017));
	episode_mo052017 =  ((month(admsn_dt) <= 05 & month(epsdenddt) >= 05 & year(epsdenddt) = 2017) | 
			(year(admsn_dt) = 2016 & month(epsdenddt) >= 05 & year(epsdenddt) = 2017));
	episode_mo062017 =  ((month(admsn_dt) <= 06 & month(epsdenddt) >= 06 & year(epsdenddt) = 2017) |
			(year(admsn_dt) = 2016 & month(epsdenddt) >= 06 & year(epsdenddt) = 2017));
	episode_mo072017 =  ((month(admsn_dt) <= 07 & month(epsdenddt) >= 07 & year(epsdenddt) = 2017) |
   			(year(admsn_dt) = 2016 & month(epsdenddt) >= 07 & year(epsdenddt) = 2017));
	episode_mo082017 =  ((month(admsn_dt) <= 08 & month(epsdenddt) >= 08 & year(epsdenddt) = 2017) |
			(year(admsn_dt) = 2016 & month(epsdenddt) >= 08 & year(epsdenddt) = 2017));
	episode_mo092017 =  ((month(admsn_dt) <= 09 & month(epsdenddt) >= 09 & year(epsdenddt) = 2017) |
			(year(admsn_dt) = 2016 & month(epsdenddt) >= 09 & year(epsdenddt) = 2017));
	episode_mo102017 =  ((month(admsn_dt) <= 10 & month(epsdenddt) >= 10 & year(epsdenddt) = 2017) |
			(year(admsn_dt) = 2016 & month(epsdenddt) >= 10 & year(epsdenddt) = 2017));
	episode_mo112017 =  ((month(admsn_dt) <= 11 & month(epsdenddt) >= 11 & year(epsdenddt) = 2017) |
			(year(admsn_dt) = 2016 & month(epsdenddt) >= 11 & year(epsdenddt) = 2017));
	episode_mo122017 =  ((month(admsn_dt) <= 12 & month(epsdenddt) >= 12 & year(epsdenddt) = 2017) |
			(year(admsn_dt) = 2016 & month(epsdenddt) >= 12 & year(epsdenddt) = 2017));	

	episode_mo012018 =  ((month(admsn_dt) <= 01 & month(epsdenddt) >= 01 & year(epsdenddt) = 2018) | 
			(year(admsn_dt) = 2017 & month(epsdenddt) >= 01 & year(epsdenddt) = 2018));
	episode_mo022018 =  ((month(admsn_dt) <= 02 & month(epsdenddt) >= 02 & year(epsdenddt) = 2018) | 
			(year(admsn_dt) = 2017 & month(epsdenddt) >= 02 & year(epsdenddt) = 2018));
	episode_mo032018 =  ((month(admsn_dt) <= 03 & month(epsdenddt) >= 03 & year(epsdenddt) = 2018) |
			(year(admsn_dt) = 2017 & month(epsdenddt) >= 03 & year(epsdenddt) = 2018));
	episode_mo042018 =  ((month(admsn_dt) <= 04 & month(epsdenddt) >= 04 & year(epsdenddt) = 2018) | 
			(year(admsn_dt) = 2017 & month(epsdenddt) >= 04 & year(epsdenddt) = 2018));
	episode_mo052018 =  ((month(admsn_dt) <= 05 & month(epsdenddt) >= 05 & year(epsdenddt) = 2018) | 
			(year(admsn_dt) = 2017 & month(epsdenddt) >= 05 & year(epsdenddt) = 2018));
	episode_mo062018 =  ((month(admsn_dt) <= 06 & month(epsdenddt) >= 06 & year(epsdenddt) = 2018) |
			(year(admsn_dt) = 2017 & month(epsdenddt) >= 06 & year(epsdenddt) = 2018));
	episode_mo072018 =  ((month(admsn_dt) <= 07 & month(epsdenddt) >= 07 & year(epsdenddt) = 2018) |
   			(year(admsn_dt) = 2017 & month(epsdenddt) >= 07 & year(epsdenddt) = 2018));
	episode_mo082018 =  ((month(admsn_dt) <= 08 & month(epsdenddt) >= 08 & year(epsdenddt) = 2018) |
			(year(admsn_dt) = 2017 & month(epsdenddt) >= 08 & year(epsdenddt) = 2018));
	episode_mo092018 =  ((month(admsn_dt) <= 09 & month(epsdenddt) >= 09 & year(epsdenddt) = 2018) |
			(year(admsn_dt) = 2017 & month(epsdenddt) >= 09 & year(epsdenddt) = 2018));
	episode_mo102018 =  ((month(admsn_dt) <= 10 & month(epsdenddt) >= 10 & year(epsdenddt) = 2018) |
			(year(admsn_dt) = 2017 & month(epsdenddt) >= 10 & year(epsdenddt) = 2018));
	episode_mo112018 =  ((month(admsn_dt) <= 11 & month(epsdenddt) >= 11 & year(epsdenddt) = 2018) |
			(year(admsn_dt) = 2017 & month(epsdenddt) >= 11 & year(epsdenddt) = 2018));
	episode_mo122018 =  ((month(admsn_dt) <= 12 & month(epsdenddt) >= 12 & year(epsdenddt) = 2018) |
			(year(admsn_dt) = 2017 & month(epsdenddt) >= 12 & year(epsdenddt) = 2018));

	drop_partAB = 0;

	if episode_mo042016 = 1 and buyin42016 ~= "3" and buyin42016 ~= "C" then drop_partAB = 1;
	if episode_mo052016 = 1 and buyin52016 ~= "3" and buyin52016 ~= "C" then drop_partAB = 1;
	if episode_mo062016 = 1 and buyin62016 ~= "3" and buyin62016 ~= "C" then drop_partAB = 1;
	if episode_mo072016 = 1 and buyin72016 ~= "3" and buyin72016 ~= "C" then drop_partAB = 1;
	if episode_mo082016 = 1 and buyin82016 ~= "3" and buyin82016 ~= "C" then drop_partAB = 1;
	if episode_mo092016 = 1 and buyin92016 ~= "3" and buyin92016 ~= "C" then drop_partAB = 1;
	if episode_mo102016 = 1 and buyin102016 ~= "3" and buyin102016 ~= "C" then drop_partAB = 1;
	if episode_mo112016 = 1 and buyin112016 ~= "3" and buyin112016 ~= "C" then drop_partAB = 1;
	if episode_mo122016 = 1 and buyin122016 ~= "3" and buyin122016 ~= "C" then drop_partAB = 1;

	if episode_mo012017 = 1 and buyin12017 ~= "3" and buyin12017 ~= "C" then drop_partAB = 1;
	if episode_mo022017 = 1 and buyin22017 ~= "3" and buyin22017 ~= "C" then drop_partAB = 1;
	if episode_mo032017 = 1 and buyin32017 ~= "3" and buyin32017 ~= "C" then drop_partAB = 1;
	if episode_mo042017 = 1 and buyin42017 ~= "3" and buyin42017 ~= "C" then drop_partAB = 1;
	if episode_mo052017 = 1 and buyin52017 ~= "3" and buyin52017 ~= "C" then drop_partAB = 1;
	if episode_mo062017 = 1 and buyin62017 ~= "3" and buyin62017 ~= "C" then drop_partAB = 1;
	if episode_mo072017 = 1 and buyin72017 ~= "3" and buyin72017 ~= "C" then drop_partAB = 1;
	if episode_mo082017 = 1 and buyin82017 ~= "3" and buyin82017 ~= "C" then drop_partAB = 1;
	if episode_mo092017 = 1 and buyin92017 ~= "3" and buyin92017 ~= "C" then drop_partAB = 1;
	if episode_mo102017 = 1 and buyin102017 ~= "3" and buyin102017 ~= "C" then drop_partAB = 1;
	if episode_mo112017 = 1 and buyin112017 ~= "3" and buyin112017 ~= "C" then drop_partAB = 1;
	if episode_mo122017 = 1 and buyin122017 ~= "3" and buyin122017 ~= "C" then drop_partAB = 1;
	
	if episode_mo012018 = 1 and buyin12018 ~= "3" and buyin12018 ~= "C" then drop_partAB = 1;
	if episode_mo022018 = 1 and buyin22018 ~= "3" and buyin22018 ~= "C" then drop_partAB = 1;
	if episode_mo032018 = 1 and buyin32018 ~= "3" and buyin32018 ~= "C" then drop_partAB = 1;
	if episode_mo042018 = 1 and buyin42018 ~= "3" and buyin42018 ~= "C" then drop_partAB = 1;
	if episode_mo052018 = 1 and buyin52018 ~= "3" and buyin52018 ~= "C" then drop_partAB = 1;
	if episode_mo062018 = 1 and buyin62018 ~= "3" and buyin62018 ~= "C" then drop_partAB = 1;
	if episode_mo072018 = 1 and buyin72018 ~= "3" and buyin72018 ~= "C" then drop_partAB = 1;
	if episode_mo082018 = 1 and buyin82018 ~= "3" and buyin82018 ~= "C" then drop_partAB = 1;
	if episode_mo092018 = 1 and buyin92018 ~= "3" and buyin92018 ~= "C" then drop_partAB = 1;
	if episode_mo102018 = 1 and buyin102018 ~= "3" and buyin102018 ~= "C" then drop_partAB = 1;
	if episode_mo112018 = 1 and buyin112018 ~= "3" and buyin112018 ~= "C" then drop_partAB = 1;
	if episode_mo122018 = 1 and buyin122018 ~= "3" and buyin122018 ~= "C" then drop_partAB = 1;

	drop_hmo = 0 ;

	if episode_mo042016 = 1 & hmo42016 ~= "0" then drop_hmo = 1;
	if episode_mo052016 = 1 & hmo52016 ~= "0" then drop_hmo = 1;
	if episode_mo062016 = 1 & hmo62016 ~= "0" then drop_hmo = 1;
	if episode_mo072016 = 1 & hmo72016 ~= "0" then drop_hmo = 1;
	if episode_mo082016 = 1 & hmo82016 ~= "0" then drop_hmo = 1;
	if episode_mo092016 = 1 & hmo92016 ~= "0" then drop_hmo = 1;
	if episode_mo102016 = 1 & hmo102016 ~= "0" then drop_hmo = 1;
	if episode_mo112016 = 1 & hmo112016 ~= "0" then drop_hmo = 1;
	if episode_mo122016 = 1 & hmo122016 ~= "0" then drop_hmo = 1;

	if episode_mo012017 = 1 & hmo12017 ~= "0" then drop_hmo = 1;
	if episode_mo022017 = 1 & hmo22017 ~= "0" then drop_hmo = 1;
	if episode_mo032017 = 1 & hmo32017 ~= "0" then drop_hmo = 1;
	if episode_mo042017 = 1 & hmo42017 ~= "0" then drop_hmo = 1;
	if episode_mo052017 = 1 & hmo52017 ~= "0" then drop_hmo = 1;
	if episode_mo062017 = 1 & hmo62017 ~= "0" then drop_hmo = 1;
	if episode_mo072017 = 1 & hmo72017 ~= "0" then drop_hmo = 1;
	if episode_mo082017 = 1 & hmo82017 ~= "0" then drop_hmo = 1;
	if episode_mo092017 = 1 & hmo92017 ~= "0" then drop_hmo = 1;
	if episode_mo102017 = 1 & hmo102017 ~= "0" then drop_hmo = 1;
	if episode_mo112017 = 1 & hmo112017 ~= "0" then drop_hmo = 1;
	if episode_mo122017 = 1 & hmo122017 ~= "0" then drop_hmo = 1;
	
	if episode_mo012018 = 1 & hmo12018 ~= "0" then drop_hmo = 1;
	if episode_mo022018 = 1 & hmo22018 ~= "0" then drop_hmo = 1;
	if episode_mo032018 = 1 & hmo32018 ~= "0" then drop_hmo = 1;
	if episode_mo042018 = 1 & hmo42018 ~= "0" then drop_hmo = 1;
	if episode_mo052018 = 1 & hmo52018 ~= "0" then drop_hmo = 1;
	if episode_mo062018 = 1 & hmo62018 ~= "0" then drop_hmo = 1;
	if episode_mo072018 = 1 & hmo72018 ~= "0" then drop_hmo = 1;
	if episode_mo082018 = 1 & hmo82018 ~= "0" then drop_hmo = 1;
	if episode_mo092018 = 1 & hmo92018 ~= "0" then drop_hmo = 1;
	if episode_mo102018 = 1 & hmo102018 ~= "0" then drop_hmo = 1;
	if episode_mo112018 = 1 & hmo112018 ~= "0" then drop_hmo = 1;
	if episode_mo122018 = 1 & hmo122018 ~= "0" then drop_hmo = 1;

	drop_esrd = bene_crec = "2";

	drop_mcareprimary = mcareprimary = 0;

	drop_readmit = 0;

	drop_die = (stus_cd = "20" or (bene_death_dt < epsdenddt AND bene_death_dt ~=.));
run;


proc sort data = tempfile out = tempfile2;
	by bene_id descending admsn_dt;
quit;

data tempfile3 (drop = next_admsn_dt);
	set tempfile2;
	by  bene_id descending admsn_dt;
	retain next_admsn_dt;
	
	if first.bene_id then next_admsn_dt = .;
	drop_readmit = 0;
		
	if ~missing(next_admsn_dt) and next_admsn_dt <= epsdenddt then drop_readmit = 1;
		
	next_admsn_dt = admsn_dt;
run;

proc sql nowarn;
	create table tempfile4 as
	select A.*, B.*
	from tempfile3 as A
	inner join temp.provider_to_msa_xwalk2016 as B
	on A.provider = B.provider;
quit;

proc sql nowarn;
	create table tempfile5 as
	select A.*, B.*
	from tempfile4 as A
	left join temp.treatment_eligible_strata as B
	on A.msa = B.msa;
quit;

proc sort nodupkey data = tempfile5;
	by bene_id admsn_dt;
quit;

data temp.index_admissions2016_2018;
	set tempfile5;
	by bene_id admsn_dt;
	match_id = _n_;
	episode_id = cat(bene_id, "_",match_id);
run;

proc sort nodupkey data = temp.index_admissions2016_2018 (keep = bene_id)
	out = temp.cjr_lejr_bene_list2016_2018;
	by bene_id;
quit;

******************************;
*OTHER UTILIZATION IN EPISODE*;
******************************;

proc sql nowarn;
	create table tempfile as
	select A.*, B.*
	from temp.ip_stay_level_loaded2016_2018 (where = (ach=1 and drg_cd~="469" and drg_cd~="470")) as A
	inner join
	temp.cjr_lejr_bene_list2016_2018 as B
	on A.bene_id=B.bene_id;
quit;
 
data temp.ip_readmission_exclusions_loaded;
	set temp.ip_readmission_exclusions;
	excl_ach = 1;	
	drg_num = input(drg_cd, 3.);
run;

data tempfile2;
    set tempfile;
	drg_num = input(drg_cd, 3.);
run;

proc sql nowarn;
	create table tempfile3 as
	select A.*, B.*
	from tempfile2 as A
	left join
	temp.ip_readmission_exclusions_loaded as B
	on A.drg_num=B.drg_num;
quit;

data temp.ach_loaded2016_2018 (keep = bene_id drg_cd ach_: excl_ach);
	set tempfile3 (rename = (admsn_dt = ach_admsndt dschrgdt = ach_dschrgdt 
	payment = ach_pay oop = ach_oop));
	ach_los = max(ach_dschrgdt - ach_admsndt, 1);	
	if missing(excl_ach) then excl_ach = 0;
run;


%macro merge_ip_cjr(filenames);
	%let filenamesn = %sysfunc(countw(&filenames.));
	%do i = 1 %to &filenamesn.;
	%let type = %scan(&filenames.,&i.);
	proc sql nowarn;
		create table tempfile as
		select A.*, B.*  
		from temp.ip_stay_level_loaded2016_2018 (where=(&type. =1)) as A
		inner join
		temp.cjr_lejr_bene_list2016_2018 as B
		on A.bene_id = B.bene_id;
	quit;

	data temp.&type._loaded2016_2018 (keep = bene_id drg_cd &type._:)  ;
		set tempfile (rename = (admsn_dt = &type._admsndt
		dschrgdt = &type._dschrgdt payment = &type._pay oop = &type._oop));
		&type._los = max(&type._dschrgdt - &type._admsndt, 1);
	run;	

	%end;
%mend;

%merge_ip_cjr(ltch irf ipf);

data temp.snf2016_2018clm;
	set mc.snf2016clm
	mc.snf2017clm
	mc.snf2018clm;
run;

proc sql nowarn;
	create table tempfile as
	select A.*, B.* 
	from temp.snf2016_2018clm as A
	inner join
	temp.cjr_lejr_bene_list2016_2018 as B
	on A.bene_id = B.bene_id;
quit;

proc sort data = tempfile out = tempfile2;
	by bene_id sadmsndt provider sdschrgdt;
quit;

data temp.snf_loaded2016_2018 (keep = bene_id snf_:);
	set tempfile2 (rename = (sadmsndt = snf_admsndt
		sdschrgdt = snf_dschrgdt));
	by bene_id snf_admsndt provider snf_dschrgdt;
	if pmt_amt < 0 then pmt_amt = 0;
	oop_amt = ded_amt + coin_amt + blddedam ;
	
	retain snf_pay snf_oop;

	if first.provider then do;
		snf_pay = pmt_amt;
		snf_oop = oop_amt;
	end;
	else do;
		snf_pay = snf_pay + pmt_amt;
		snf_oop = snf_oop + oop_amt;
	end;
	
	if last.provider;
	
	snf_dschrg_impute_flag = missing(snf_dschrgdt);
	if missing(snf_dschrgdt) then snf_dschrgdt = snf_admsndt + 100;
	snf_los = snf_dschrgdt - snf_admsndt;
run;

%macro merge_hha_hos_cjr(filenames);
%let filenamesn = %sysfunc(countw(&filenames.));
%do i = 1 %to &filenamesn.;
%let type = %scan(&filenames.,&i.);

data temp.&type.2016_2018clm;
	set mc.&type.2016clm
	mc.&type.2017clm
	mc.&type.2018clm;
run;

proc sql nowarn;
	create table tempfile as
	select A.*, B.*  
	from temp.&type.2016_2018clm as A
	inner join
	temp.cjr_lejr_bene_list2016_2018 as B
	on A.bene_id = B.bene_id;
quit;

data temp.&type._loaded2016_2018 (keep = bene_id &type._:)  ;
	set tempfile (rename = (sfromdt = &type._admsndt sthrudt = &type._dschrgdt
	pmt_amt = &type._pay));
	if pmt_amt < 0 then pmt_amt = 0;
	&type._oop = 0;
	&type._los = &type._dschrgdt - &type._admsndt + 1;    
run;	

%end;
%mend;

%merge_hha_hos_cjr(hha hos);


data temp.dme2016_2018lnit;
	set mc.dme2016lnit
	mc.dme2017lnit
	mc.dme2018lnit;
run;

proc sql nowarn;
	create table temp.dme_oop2016_2018
	as select clm_id, sum(ldedamt) as ldedamt, sum(coinamt) as coinamt
	from temp.dme2016_2018lnit (keep = clm_id ldedamt coinamt)
	group by clm_id;
quit;

data temp.dme2016_2018clm;
	set mc.dme2016clm
	mc.dme2017clm
	mc.dme2018clm;
run;

proc sql nowarn;
	create table temp.tempfile as
	select A.*, B.*
	from temp.dme2016_2018clm as A
	inner join
	temp.cjr_lejr_bene_list2016_2018 as B
	on A.bene_id=B.bene_id;
quit;

proc sql nowarn;
	create table temp.tempfile2 as
	select A.*, B.*
	from temp.tempfile as A
	inner join
	temp.dme_oop2016_2018 as B
	on A.clm_id=B.clm_id;
quit;

data temp.dme_loaded2016_2018 (keep = bene_id dme_:) ;
    set temp.tempfile2 (rename = (sfromdt = dme_admsndt sthrudt = dme_dschrgdt pmt_amt = dme_pay));
	dme_oop = ldedamt + coinamt;
	if pmt_amt < 0 then pmt_amt = 0;
    dme_los = dme_dschrgdt - dme_admsndt + 1;
run;

data tempfile;
    set mc.op2016revp1(keep = clm_id revpmt rev_cntr)
	mc.op2016revp2(keep = clm_id revpmt rev_cntr)
	mc.op2016revp3(keep = clm_id revpmt rev_cntr)
	mc.op2016revp4(keep = clm_id revpmt rev_cntr)
	mc.op2016revp5(keep = clm_id revpmt rev_cntr)
	mc.op2017revp1(keep = clm_id revpmt rev_cntr)
	mc.op2017revp2(keep = clm_id revpmt rev_cntr)
	mc.op2017revp3(keep = clm_id revpmt rev_cntr)
	mc.op2017revp4(keep = clm_id revpmt rev_cntr)
	mc.op2017revp5(keep = clm_id revpmt rev_cntr)
	mc.op2018revp1(keep = clm_id revpmt rev_cntr)
	mc.op2018revp2(keep = clm_id revpmt rev_cntr)
	mc.op2018revp3(keep = clm_id revpmt rev_cntr)
	mc.op2018revp4(keep = clm_id revpmt rev_cntr)
	mc.op2018revp5(keep = clm_id revpmt rev_cntr);
run; 	

data tempfile_er;
	set tempfile (keep = clm_id rev_cntr);
	ER_visit = 0;
	if rev_cntr in ("0450", "0451", "0452", "0453", "0454", "0455",
		"0456", "0457", "0458", "0459", "0981") then ER_visit = 1;
run;

proc sql nowarn;
	create table temp.opr_er2016_2018 as
	select clm_id, max(ER_visit) as ER_visit
	from tempfile_er
	group by clm_id;
quit;

data tempfile;
    set mc.op2016clmp1(keep = clm_id bene_id sfromdt sthrudt pmt_amt ptb_ded ptb_coin blddedam)
	mc.op2016clmp2(keep = clm_id bene_id sfromdt sthrudt pmt_amt ptb_ded ptb_coin blddedam)
	mc.op2016clmp3(keep = clm_id bene_id sfromdt sthrudt pmt_amt ptb_ded ptb_coin blddedam)
	mc.op2016clmp4(keep = clm_id bene_id sfromdt sthrudt pmt_amt ptb_ded ptb_coin blddedam)
	mc.op2016clmp5(keep = clm_id bene_id sfromdt sthrudt pmt_amt ptb_ded ptb_coin blddedam)
	mc.op2017clmp1(keep = clm_id bene_id sfromdt sthrudt pmt_amt ptb_ded ptb_coin blddedam)
	mc.op2017clmp2(keep = clm_id bene_id sfromdt sthrudt pmt_amt ptb_ded ptb_coin blddedam)	
	mc.op2017clmp3(keep = clm_id bene_id sfromdt sthrudt pmt_amt ptb_ded ptb_coin blddedam)
	mc.op2017clmp4(keep = clm_id bene_id sfromdt sthrudt pmt_amt ptb_ded ptb_coin blddedam)
	mc.op2017clmp5(keep = clm_id bene_id sfromdt sthrudt pmt_amt ptb_ded ptb_coin blddedam)
	mc.op2018clmp1(keep = clm_id bene_id sfromdt sthrudt pmt_amt ptb_ded ptb_coin blddedam)
	mc.op2018clmp2(keep = clm_id bene_id sfromdt sthrudt pmt_amt ptb_ded ptb_coin blddedam)	
	mc.op2018clmp3(keep = clm_id bene_id sfromdt sthrudt pmt_amt ptb_ded ptb_coin blddedam)
	mc.op2018clmp4(keep = clm_id bene_id sfromdt sthrudt pmt_amt ptb_ded ptb_coin blddedam)
	mc.op2018clmp5(keep = clm_id bene_id sfromdt sthrudt pmt_amt ptb_ded ptb_coin blddedam);
run; 	

proc sql nowarn;
	create table tempfile2 as
	select A.*, B.*
	from tempfile as A
	inner join
	temp.cjr_lejr_bene_list2016_2018 as B
	on A.bene_id=B.bene_id;
quit;
	
data tempfile3;
	set tempfile2 (rename  = (sfromdt = op_admsndt
			sthrudt = op_dschrgdt
			pmt_amt = op_pay));
	if op_pay<0 then op_pay = 0;
	
	op_oop = ptb_ded + ptb_coin + blddedam;
	
	keep bene_id clm_id op_: ;
	op_los = op_dschrgdt - op_admsndt + 1;
run;

proc sql nowarn;
	create table temp.op_loaded2016_2018 as
	select A.*, B.*
	from tempfile3 as A
	left join
	temp.opr_er2016_2018 as B
	on A.clm_id = B.clm_id;
quit;

data tempfile;
	set mc.ptb2016lnitp1(keep = clm_id ldedamt coinamt)
	mc.ptb2016lnitp2(keep = clm_id ldedamt coinamt)
	mc.ptb2016lnitp3(keep = clm_id ldedamt coinamt)
	mc.ptb2016lnitp4(keep = clm_id ldedamt coinamt)
	mc.ptb2016lnitp5(keep = clm_id ldedamt coinamt)
	mc.ptb2017lnitp1(keep = clm_id ldedamt coinamt)
	mc.ptb2017lnitp2(keep = clm_id ldedamt coinamt)	
	mc.ptb2017lnitp3(keep = clm_id ldedamt coinamt)	
	mc.ptb2017lnitp4(keep = clm_id ldedamt coinamt)
	mc.ptb2017lnitp5(keep = clm_id ldedamt coinamt)
	mc.ptb2018lnitp1(keep = clm_id ldedamt coinamt)
	mc.ptb2018lnitp2(keep = clm_id ldedamt coinamt)	
	mc.ptb2018lnitp3(keep = clm_id ldedamt coinamt)	
	mc.ptb2018lnitp4(keep = clm_id ldedamt coinamt)
	mc.ptb2018lnitp5(keep = clm_id ldedamt coinamt);
run;

proc sql nowarn;
	create table temp.car_oop2016_2018 as
	select clm_id, sum(ldedamt) as ldedamt, sum(coinamt) as coinamt
	from tempfile 
	group by clm_id;
quit;

data tempfile;
	set mc.ptb2016clmp1(keep = clm_id bene_id sfromdt sthrudt pmt_amt dgns_cd1)
	mc.ptb2016clmp2(keep = clm_id bene_id sfromdt sthrudt pmt_amt dgns_cd1)
	mc.ptb2016clmp3(keep = clm_id bene_id sfromdt sthrudt pmt_amt dgns_cd1)
	mc.ptb2016clmp4(keep = clm_id bene_id sfromdt sthrudt pmt_amt dgns_cd1)
	mc.ptb2016clmp5(keep = clm_id bene_id sfromdt sthrudt pmt_amt dgns_cd1)
	mc.ptb2017clmp1(keep = clm_id bene_id sfromdt sthrudt pmt_amt dgns_cd1)
	mc.ptb2017clmp2(keep = clm_id bene_id sfromdt sthrudt pmt_amt dgns_cd1)
	mc.ptb2017clmp3(keep = clm_id bene_id sfromdt sthrudt pmt_amt dgns_cd1)
	mc.ptb2017clmp4(keep = clm_id bene_id sfromdt sthrudt pmt_amt dgns_cd1)
	mc.ptb2017clmp5(keep = clm_id bene_id sfromdt sthrudt pmt_amt dgns_cd1)
	mc.ptb2018clmp1(keep = clm_id bene_id sfromdt sthrudt pmt_amt dgns_cd1)
	mc.ptb2018clmp2(keep = clm_id bene_id sfromdt sthrudt pmt_amt dgns_cd1)
	mc.ptb2018clmp3(keep = clm_id bene_id sfromdt sthrudt pmt_amt dgns_cd1)
	mc.ptb2018clmp4(keep = clm_id bene_id sfromdt sthrudt pmt_amt dgns_cd1)
	mc.ptb2018clmp5(keep = clm_id bene_id sfromdt sthrudt pmt_amt dgns_cd1);
	prncpal_dgns_cd = compress(dgns_cd1,".");
run;

proc sql nowarn;
	create table tempfile2 as
	select A.*, B.*
	from tempfile as A
	inner join
	temp.cjr_lejr_bene_list2016_2018 as B
	on A.bene_id=B.bene_id;
quit;
	
proc sql nowarn;
	create table tempfile3 as
	select A.*, B.*
	from tempfile2  as A
	inner join
	temp.car_oop2016_2018 as B
	on A.clm_id=B.clm_id;
quit;


proc sort data =  temp.ptb_excluded_icd10
	out = temp.ptb_excluded_icd10;
	by prncpal_dgns_cd;
quit;

proc sort data =  tempfile3
	out = tempfile4;
	by prncpal_dgns_cd;
quit;

proc sql nowarn;

	create table tempfile5 as
	select A.*, B.*, case when A.prncpal_dgns_cd = B.prncpal_dgns_cd then 1 end as excl_ptb
	from tempfile4 as A
	left join
	temp.ptb_excluded_icd10 as B
	on A.prncpal_dgns_cd=B.prncpal_dgns_cd;

quit;

data temp.car_loaded2016_2018;
	set tempfile5 (rename = (sfromdt = car_admsndt
        sthrudt = car_dschrgdt
        pmt_amt = car_pay));
	if pmt_amt<0 then pmt_amt = 0;
	car_oop = ldedamt + coinamt;
	car_los = car_dschrgdt - car_admsndt + 1;
	if missing(excl_ptb) then excl_ptb = 0;
	keep bene_id prncpal_dgns_cd car_: excl_ptb;
run;

*************************;
* ALL CAUSE READMISSIONS*;
*************************;

proc sort data =  temp.ip_stay_level_loaded2016_2018 (where = ( (prvdrnum <= 999 & ~missing(prvdrnum)) or (prvdrnum >= 1300 and prvdrnum <= 1399)))
	out = tempfile;
	by bene_id descending admsn_dt;
quit;

data temp.all_cause_readmission2016_2018 (keep = bene_id provider admsn_dt all_cause_readmit);
	set tempfile;
	by  bene_id descending admsn_dt;
	retain next_admsn_dt;
	
	if first.bene_id then next_admsn_dt = .;
	all_cause_readmit = 0;
		
	if ~missing(next_admsn_dt) and next_admsn_dt <= dschrgdt + 89 then all_cause_readmit = 1;
		
	next_admsn_dt = admsn_dt;
run;


***********;
*ER VISITS*;
***********;

data tempfile;
	set mc.ip2016rev
	mc.ip2017rev
	mc.ip2018rev;
	ER_visit = 0;
	if rev_cntr in ("0450", "0451", "0452", "0453", "0454", "0455",
					"0456", "0457", "0458", "0459", "0981") then ER_visit = 1;
	if ER_visit = 1;
	keep clm_id ER_visit; 
run;

proc sort nodupkey data = tempfile out = temp.ipr_er2016_2018;
	by ER_visit clm_id;
quit;

data tempfile;
	set mc.ip2016clm
	mc.ip2017clm
	mc.ip2018clm;
	prvdstr = substr(provider, 3, 4);
	if anyalpha(prvdstr) = 0 then prvdrnum = input(prvdstr, 4.); 

	ach  = ((prvdrnum <= 999 & ~missing(prvdrnum)) | (prvdrnum >= 1300 & prvdrnum <= 1399))  ;
	
	if drg_cd in ("469", "470") and ach = 1 then delete;
run;

proc sql nowarn;
	create table tempfile2 as 
	select A.*, B.ER_visit 
	from tempfile as A
	inner join
	temp.ipr_er2016_2018 as B
	on A.clm_id = B.clm_id;
quit;

data temp.ip_er_temp2016_2018;
	set tempfile2(keep=bene_id ER_visit sadmsndt sdschrgdt
	rename = (sadmsndt = ER_admsndt sdschrgdt = ER_dschrgdt));
run;

data temp.op_er_temp2016_2018;
	set temp.op_loaded2016_2018 (keep=bene_id ER_visit op_admsndt op_dschrgdt
	rename = (op_admsndt = ER_admsndt op_dschrgdt = ER_dschrgdt));
	if ER_visit = 1;
run;

data tempfile;
	set temp.ip_er_temp2016_2018 temp.op_er_temp2016_2018;
run;
proc sort nodupkey data = tempfile out = temp.ER_loaded2016_2018;
	by bene_id ER_admsndt descending ER_dschrgdt;
quit;


**************************;
*DEFINE CJR LEJR EPISODES*;
**************************;

%macro typelist_prog1(filenames);
	%let filenamesn = %sysfunc(countw(&filenames.));
	%do i = 1 %to &filenamesn.;
	%let type = %scan(&filenames.,&i.);
	proc sql nowarn;
		create table tempfile as
		select A.*, B.*
		from temp.&type._loaded2016_2018 as A
		inner join
		temp.index_admissions2016_2018 as B
		on A.bene_id = B.bene_id;
	quit;

	data temp.&type._in_episode_id_2016_2018;
		set tempfile;
		if &type._admsndt >= admsn_dt and &type._admsndt <= epsdenddt;
	run;
	%end;
%mend;

%typelist_prog1(ach ltch irf ipf snf dme hos op car ER);
%let type = hha;

proc sql nowarn;
	create table tempfile as
	select A.*, B.*
	from temp.&type._loaded2016_2018 as A
	inner join
	temp.index_admissions2016_2018 as B
	on A.bene_id = B.bene_id;
quit;

data temp.&type._in_episode_id_2016_2018;
	set tempfile;
	if (&type._admsndt >= admsn_dt and &type._admsndt <= epsdenddt)
		or (&type._admsndt < admsn_dt & &type._dschrgdt >= admsn_dt) ;
run;

proc sql nowarn;
	create table temp.ER_in_episode_2016_2018 as
	select episode_id, max(ER_visit) as ER_visit
	from temp.er_in_episode_id_2016_2018
	group by episode_id;
quit;

%macro typelist_prog2(filenames);
	%let filenamesn = %sysfunc(countw(&filenames.));
	%do i = 1 %to &filenamesn.;
	%let type = %scan(&filenames.,&i.);
	data tempfile;
		set temp.&type._in_episode_id_2016_2018;
		prorate_flag = (epsdenddt < &type._dschrgdt);
		if prorate_flag = 1 then do; 
			prorate_los = &type._los - (&type._dschrgdt - epsdenddt);
			prorate_pay = (prorate_los / &type._los) * &type._pay;
			prorate_oop = (prorate_los / &type._los) * &type._oop;
			&type._los = prorate_los ;
			&type._pay = prorate_pay ;
			&type._oop = prorate_oop ;
		end;
	run;

	proc sql;
		create table temp.&type._in_episode_2016_2018 as
		select episode_id, sum(&type._pay) as &type._pay, sum(&type._los) as &type._los,
		 sum(&type._oop) as &type._oop 
		from tempfile
		group by episode_id;
	quit;
	%end;
%mend;

%typelist_prog2(ltch irf ipf snf dme hos);

%let type = hha;

data tempfile;
	set temp.&type._in_episode_id_2016_2018;
	
	prorate_flag_dschrg = (epsdenddt < hha_dschrgdt);
	prorate_flag_admsn = (hha_admsndt < admsn_dt);
	if prorate_flag_dschrg = 1 & prorate_flag_admsn = 0 then 
		prorate_los = hha_los - (hha_dschrgdt - epsdenddt);
		
	if prorate_flag_dschrg = 0 & prorate_flag_admsn = 1 then   
        prorate_los = hha_los -(admsn_dt - hha_admsndt);
    
	if prorate_flag_dschrg = 1 & prorate_flag_admsn = 1 then
		prorate_los = hha_los - (hha_dschrgdt - epsdenddt) - (admsn_dt - hha_admsndt);
    
	if (prorate_flag_dschrg = 1 | prorate_flag_admsn = 1) then do;
		prorate_pay = (prorate_los / hha_los) * hha_pay;
		hha_los = prorate_los;
		hha_pay = prorate_pay;
	end;	 
run;

proc sql nowarn;
	create table temp.hha_in_episode_2016_2018 as
	select episode_id, sum(&type._pay) as &type._pay, sum(&type._los) as &type._los,
	 sum(&type._oop) as &type._oop 
	from tempfile
	group by episode_id;
quit;

%let type = ach;

data temp.&type._in_episode_id_2016_2018_temp;
	set temp.&type._in_episode_id_2016_2018(rename=(drg_cd=drg_cd_str));
	drg_cd = input(drg_cd_str, 8.);
run;

proc sql nowarn;
	create table tempfile as
	select A.*, B.* 
	from temp.&type._in_episode_id_2016_2018_temp as A
	left join  temp.drg_gmlos2015 as B
	on A.drg_cd = B.drg_cd;
quit;

data tempfile2;
	set tempfile;
	prorate_flag = (epsdenddt < ach_dschrgdt);
	if prorate_flag = 1 then do;	
		prorate_los = ach_los - (ach_dschrgdt - epsdenddt);
		ach_los = prorate_los ;
	end;
	if prorate_flag = 1 & prorate_los < gmlos & ~missing(gmlos) then do;
		prorate_pay = ach_pay/gmlos * (1+prorate_los);
		prorate_oop = ach_oop/gmlos * (1+prorate_los);
        ach_pay = prorate_pay ;
        ach_oop = prorate_oop ;
	end;
run;

proc sql nowarn;
	create table temp.&type._in_episode_2016_2018 as
	select episode_id, excl_ach, sum(&type._pay) as &type._pay, sum(&type._los) as &type._los,
	 sum(&type._oop) as &type._oop
	from tempfile2 (where = (excl_ach=0))
	group by episode_id, excl_ach;
quit;

proc sql nowarn;
	create table temp.excl_ach_in_episode_2016_2018 as
	select episode_id, excl_ach, sum(&type._pay) as excl_&type._pay, sum(&type._los) as excl_&type._los,
	 sum(&type._oop) as excl_&type._oop
	from tempfile2 (where = (excl_ach=1))
	group by episode_id, excl_ach;
quit;
	
%let type = op;

data tempfile;
	set temp.&type._in_episode_id_2016_2018;
	
	prorate_flag = epsdenddt < op_dschrgdt;
	if prorate_flag = 1 then do;
		prorate_los = op_los - (op_dschrgdt - epsdenddt) ;
        prorate_pay = (prorate_los / op_los) * op_pay; 
        prorate_oop = (prorate_los / op_los) * op_oop; 
	*prorate_exclpay = (prorate_los / op_los) * exclpay_medv_passthru;
        op_los = prorate_los;
        op_pay = prorate_pay;
        op_oop = prorate_oop;
	*exclpay_medv_passthru = prorate_exclpay;
    end;
run;

proc sql nowarn;
	create table temp.&type._in_episode_2016_2018 as
	select episode_id, sum(&type._pay) as &type._pay, sum(&type._los) as &type._los,
	sum(&type._oop) as &type._oop
	from tempfile
	group by episode_id;
quit;

%let type = car;

data tempfile;
	set temp.&type._in_episode_id_2016_2018;
	
	prorate_flag = epsdenddt < car_dschrgdt;

	if prorate_flag = 1 then do;
		prorate_los = car_los - (car_dschrgdt - epsdenddt) ;
        	prorate_pay = (prorate_los / car_los) * car_pay; 
        	prorate_oop = (prorate_los / car_los) * car_oop; 
        	car_los = prorate_los;
        	car_pay = prorate_pay;
        	car_oop = prorate_oop;
	end;
run;

proc sql;
	create table temp.&type._in_episode_2016_2018 as
	select episode_id, sum(&type._pay) as &type._pay, sum(&type._los) as &type._los,
	 sum(&type._oop) as &type._oop
	from tempfile (where = (excl_ptb = 0))
	group by episode_id;
quit;

proc sql;
	create table temp.excl_&type._in_episode_2016_2018 as
	select episode_id, sum(&type._pay) as excl_&type._pay, sum(&type._los) as excl_&type._los,
	 sum(&type._oop) as excl_&type._oop
	from tempfile (where = (excl_ptb = 1))
	group by episode_id;
quit;

* Merge CJR index admissions with other files;

%let type = ach;
proc sql nowarn;
	create table tempfile as
	select A.*, B.*
	from temp.index_admissions2016_2018 as A
	left join temp.&type._in_episode_2016_2018 as B
	on A.episode_id = B.episode_id;
run;

%macro typelist_prog3(filenames);
	%let filenamesn = %sysfunc(countw(&filenames.));
	%do i = 1 %to &filenamesn.;
	%let type = %scan(&filenames.,&i.);
	proc sql nowarn undo_policy = none;
		create table tempfile as
		select A.*, B.*
		from tempfile as A
		left join temp.&type._in_episode_2016_2018 as B
		on A.episode_id = B.episode_id;
	run;
	%end;
%mend;

%typelist_prog3(ltch irf ipf snf hha dme hos op car excl_ach excl_car);

proc sql nowarn;
	create table tempfile2 as
	select A.*, B.*
	from tempfile as A
	left join temp.ER_in_episode_2016_2018 as B
	on A.episode_id = B.episode_id;
run;

proc sql nowarn;
	create table tempfile3 as
	select A.*, B.*
	from tempfile2 as A
	left join temp.all_cause_readmission2016_2018 as B
	on A.bene_id = B.bene_id and A.provider = B.provider and A.admsn_dt = B.admsn_dt ;
run;

data output.all_episode_level_data2016_2018 ;
	set tempfile3;
	array payarr {*} ach_pay ltch_pay irf_pay ipf_pay snf_pay hha_pay dme_pay hos_pay op_pay car_pay excl_ach_pay excl_car_pay;
	array losarr {*} ach_los ltch_los irf_los ipf_los snf_los hha_los dme_los hos_los op_los car_los excl_ach_los excl_car_los;
	array ooparr {*} ach_oop ltch_oop irf_oop ipf_oop snf_oop hha_oop dme_oop hos_oop op_oop car_oop excl_ach_oop excl_car_oop;
	
	do i = 1 to 12 ;
		if missing(payarr[i]) then payarr[i] = 0;
		if missing(losarr[i]) then losarr[i] = 0;
		if missing(ooparr[i]) then ooparr[i] = 0;
	end;
	
	if ER_visit = . then ER_visit = 0 ;
	*if exclpay_medv_passthru = . then  exclpay_medv_passthru = 0 ;

	tot_pay = index_pay + ach_pay + ltch_pay + irf_pay + ipf_pay 
          + car_pay + snf_pay + hha_pay + dme_pay + hos_pay + op_pay;
	tot_oop = index_oop + ach_oop + ltch_oop + irf_oop + ipf_oop
          + car_oop + snf_oop + hha_oop + dme_oop + hos_oop + op_oop;
	tot_nonindex_pay =  ach_pay + ltch_pay + irf_pay + ipf_pay
          + car_pay + snf_pay + hha_pay + dme_pay + hos_pay + op_pay;
		
	pac_pay = ltch_pay + irf_pay + snf_pay + hha_pay;
	
	inst_pac_pay = ltch_pay + irf_pay + snf_pay;
	
	inst_pac_los = ltch_los + irf_los + snf_los;

	cjr_sample = (drop_pps = 0 & drop_bpci = 0 & drop_partAB = 0 & drop_esrd = 0 & 
        drop_hmo = 0 & drop_mcareprimary = 0 & drop_readmit = 0 & drop_die = 0);

	drop episode_mo: buyin1-buyin12 hmo1-hmo12 ;
	
	dschrg_pac = (stus_cd in ("03", "06", "62", "63", "83", "86", "90", "91"));
	dschrg_inst_pac = (stus_cd in ("03", "62", "63", "83", "90", "91")) ;
	if dschrg_pac = 1 then inst_pac_if_any_pac = dschrg_inst_pac ;

	drop ach excl_ach ipf irf ltch i;
	
run;

