version 15
set more off
adopath + ../external/lib/stata/gslab_misc/ado
adopath + ../external/lib/stata/ado
preliminaries

global data_dir = "[DATA DIR]"
global ext = "[EXT DIR]"

global Ext_Outcomes = "lejr_rate cjr_rate"

program main

    foreach year in 2012 2013 2014 2016_2017 {
        load_numerator, year(`year')
    }
    load_extensive_margin_data, pre_years(2012 2013) analysis_year(2014) analysis_denom(2014)
    load_extensive_margin_data, pre_years(2013 2014) analysis_year(2016_2017) analysis_denom(2016)

end

program load_numerator
    syntax, year(str)
    
    use if Final_MSAs == 1 ///
        using "$ext/Episode Level Data/output/all_episode_level_data`year'", clear
    rename *, lower
    rename treatment Treatment
    rename control Control    
    gen lejr_rate = 1
    rename cjr_sample cjr_rate
    collapse (sum) $Ext_Outcomes (mean) Treatment Control strata, by(msa)
    save "${data_dir}/temp/numerator`year'", replace
end

program load_extensive_margin_data
    syntax, pre_years(str) analysis_year(str) analysis_denom(str)

    foreach year in `pre_years' {
        use "$ext/MSA Level Data SAS/output/tm_sample_msa`year'", clear
	rename n N
        merge 1:1 msa using "${data_dir}/temp/numerator`year'", assert(1 3) keep(3) nogen
        foreach var in $Ext_Outcomes {
            replace `var' = (`var'/N)*1000
            rename `var' `var'_`year'
        }
        save "${data_dir}/temp/ext_`year'", replace
    }
    use "$ext/MSA Level Data SAS/output/tm_sample_msa`analysis_denom'", clear 
    rename n N       
    merge 1:1 msa using "${data_dir}/temp/numerator`analysis_year'", assert(1 3) keep(3) nogen
    xi i.strata, pref(_) noomit
    drop _strata_1

    foreach year in `pre_years' {
        merge 1:1 msa using "${data_dir}/temp/ext_`year'", assert(3) keep(3) nogen
    }
    foreach var in $Ext_Outcomes {
        replace `var' = (`var'/N)*1000
    }
    save "${data_dir}/temp/msa_ext_outcomes_`analysis_year'", replace

end


* Execute
main