version 15
set more off
preliminaries

global data_dir = "[DATA DIR]"
global ext = "[EXT DIR]"

global Utilization = "tot_spend index_spend inst_pac_spend hha_spend other_spend index_los inst_pac_los"
global Utilization = "$Utilization dschrg_inst_pac dschrg_hha dschrg_home dschrg_other NetPay" 
global Quality = "thatka_comp er_visit all_cause_readmit"
global PatMix = "lejr_rate cjr_rate elixsum"
global Outcomes = "$Utilization $Quality $PatMix"
global PreYear = "2013 2014"
global AnalysisYear = "2016_2017"

program main

    generate_cjr_count
    generate_all_cause_readmission
    generate_thatka_comp
    load_elixsum
    gen_analysis_tables
    make_tables

end

program generate_cjr_count

    foreach year in $PreYear {
        use if cjr_sample == 1 & Final_MSAs == 1 using ///
		    "$ext/Episode Level Data/output/all_episode_level_data`year'.dta", clear
		gen cjr_count = 1
		collapse (sum) cjr_count,by(msa)
        rename cjr_count cjr_count_`year'
		save "${data_dir}/temp/cjr_count_`year'.dta", replace
	}
end

program generate_all_cause_readmission

    foreach year in $PreYear {
        use "$ext/Episode Level Data/output/all_episode_level_data`year'.dta", clear
        keep if drop_bpci ==0 & drop_die == 0 & drop_esrd ==0 & drop_hmo==0 & ///
            drop_mcare==0 & drop_partAB==0 & drop_pps==0
        // the sample is all LEJR that pass all CJR criteria except for readmission (since we 
        // want to summarize the frequency of readmissions for all DRGs we cannot drop the CJR
        // episodes due to LEJR readmission
		
	    * Keep only providers from the baseline
	    merge m:1 provider using "$ext/Analysis Data/output/provider_level_data_baseline", ///
	        keep(3) keepusing(provider) nogen
			
        collapse (mean) all_cause_readmit, by(msa)
        rename all_cause_readmit all_cause_readmit_`year'
        save "${data_dir}/temp/all_cause_readmit_`year'", replace
    }
    use "$ext/Episode Level Data/output/all_episode_level_data$AnalysisYear.dta", clear
    keep if drop_bpci ==0 & drop_die == 0 & drop_esrd ==0 & drop_hmo==0 & ///
        drop_mcare==0 & drop_partAB==0 & drop_pps==0

    keep if Final_MSAs == 1
	
	* Keep only providers from the baseline
	merge m:1 provider using "$ext/Analysis Data/output/provider_level_data_baseline", ///
	    keep(3) keepusing(provider) nogen
		
    collapse (mean) all_cause_readmit, by(msa)
    
    foreach year in $PreYear {
        merge 1:1 msa using "${data_dir}/temp/all_cause_readmit_`year'", assert(1 2 3) keep(3) nogen
    }
    save "${data_dir}/temp/msa_all_cause_readmit_$AnalysisYear", replace

end

program generate_thatka_comp

    foreach year in $PreYear {
        use "$ext/Episode Level Data/output/all_episode_level_data`year'.dta", clear
	    merge 1:1 episode_id using ///
	        "$ext/THATKA Complications/output/thatka_comp`year'.dta", assert(3) keep(3) nogen
        keep if drop_bpci ==0 & drop_esrd ==0 & drop_hmo==0 & ///
            drop_mcare==0 & drop_partAB==0 & drop_pps==0
        // the sample is all LEJR that pass all CJR criteria except for death
	    // and readmission
	
	    * Keep only providers from the baseline
	    merge m:1 provider using "$ext/Analysis Data/output/provider_level_data_baseline", ///
	        keep(3) keepusing(provider) nogen
			
        collapse (mean) thatka_comp = thatka_comp_flag, by(msa)
        rename thatka_comp thatka_comp_`year'
        save "${data_dir}/temp/thatka_comp_`year'", replace
    }
    use "$ext/Episode Level Data/output/all_episode_level_data$AnalysisYear.dta", clear
    merge 1:1 episode_id using ///
        "$ext/THATKA Complications/output/thatka_comp$AnalysisYear.dta", assert(3) keep(3) nogen
    keep if drop_bpci ==0 & drop_esrd ==0 & drop_hmo==0 & ///
        drop_mcare==0 & drop_partAB==0 & drop_pps==0
        // the sample is all LEJR that pass all CJR criteria except for death
	// and readmission
    keep if Final_MSAs == 1
	
    * Keep only providers from the baseline
    merge m:1 provider using "$ext/Analysis Data/output/provider_level_data_baseline", ///
	    keep(3) keepusing(provider) nogen
			
    collapse (mean) thatka_comp = thatka_comp_flag, by(msa)
    foreach year in $PreYear {
        merge 1:1 msa using "${data_dir}/temp/thatka_comp_`year'", ///
	    assert(1 2 3) keep(1 2 3) keepusing(thatka_comp_`year') nogen
    }
    save "${data_dir}/temp/msa_thatka_comp_$AnalysisYear", replace

end

program load_elixsum

    foreach year in $PreYear {
        use "$ext/Episode Level Data/output/all_episode_level_data`year'.dta", clear
	    keep if cjr_sample == 1 & OrigElig == 1
        merge 1:1 episode_id using "$ext/Elixhauser/output/elix`year'.dta", ///
	    assert(2 3) keep(3) nogen

        * Keep only providers from the baseline
        merge m:1 provider using "$ext/Analysis Data/output/provider_level_data_baseline", ///
            keep(3) keepusing(provider) nogen
			
	    collapse (mean) elixsum, by(msa)
        rename elixsum elixsum_`year'
        
        save "${data_dir}/temp/elix_`year'", replace
    }
    
    use if cjr_sample == 1 & OrigElig == 1 using ///
        "$ext/Episode Level Data/output/all_episode_level_data$AnalysisYear.dta", clear
    merge 1:1 episode_id using "$ext/Elixhauser/output/elix$AnalysisYear.dta", ///
	assert(2 3) keep(3) nogen
   
    keep if Final_MSAs == 1	
    
	* Keep only providers from the baseline
    merge m:1 provider using "$ext/Analysis Data/output/provider_level_data_baseline", ///
        keep(3) keepusing(provider) nogen
		
    collapse (mean) elixsum, by(msa)
	
    foreach year in $PreYear {
        merge 1:1 msa using "${data_dir}/temp/elix_`year'", ///
	    assert(1 2 3) keep(1 2 3) keepusing(elixsum_`year') nogen
    }
    save "${data_dir}/temp/msa_elix_$AnalysisYear", replace

end

program gen_analysis_tables

    use "$ext/Analysis Data/output/episode_level_data2016_2017.dta", clear
    * Keep only providers from the baseline
    merge m:1 provider using "$ext/Analysis Data/output/provider_level_data_baseline", ///
        keep(3) keepusing(provider) nogen
		
    egen num_bene_post = tag(bene_id provider)
    gen num_epsd_post = 1
    keep if Final_MSAs == 1   
    gen cjr_count = num_epsd_post

    collapse (sum) num_bene_post num_epsd_post cjr_count (mean) $Utilization er_visit Control Treatment strata *_2013 *_2014, by(msa)
    xi i.strata, pref(_) noomit
    drop _strata_1
    merge 1:1 msa using "${data_dir}/temp/msa_all_cause_readmit_$AnalysisYear", assert(2 3) keep(3) nogen
    merge 1:1 msa using "${data_dir}/temp/msa_elix_$AnalysisYear", assert(2 3) keep(3) nogen
    merge 1:1 msa using "${data_dir}/temp/msa_thatka_comp_$AnalysisYear", assert(2 3) keep(3) nogen
    merge 1:1 msa using "${data_dir}/temp/msa_ext_outcomes_$AnalysisYear", assert(2 3) keep(3) nogen
    merge 1:1 msa using "${data_dir}/temp/cjr_count_2013", assert(3) keep(3) nogen
	merge 1:1 msa using "${data_dir}/temp/cjr_count_2014", assert(3) keep(3) nogen

	save "$ext/Analysis Data/temp/analysis_data_loaded", replace
	
	use "$ext/Analysis Data/temp/analysis_data_loaded", clear

    * Means (Control)
    foreach outcome in $Outcomes {
        summ `outcome' if Control == 1
        matrix analysis_means = nullmat(analysis_means) \ (`r(mean)' , `r(sd)')
    }

    * OLS
    foreach outcome in $Outcomes {
        if "`outcome'" == "cqs" {
            reg `outcome' Treatment _strata*, r
            local p_value = 2 * ttail(e(df_r), abs(_b[Treatment]/_se[Treatment]))
            matrix analysis_ols = nullmat(analysis_ols) \ ///
                (_b[Treatment] , _se[Treatment], _b[Treatment]-invt(e(df_r), .975)*_se[Treatment] ///
	        , _b[Treatment ]+ invt(e(df_r), .975)*_se[Treatment] , `p_value')
        }
        else {
            reg `outcome' Treatment _strata* `outcome'_2013 `outcome'_2014, r
            local p_value = 2 * ttail(e(df_r), abs(_b[Treatment]/_se[Treatment]))
            matrix analysis_ols = nullmat(analysis_ols) \ ///
                (_b[Treatment] , _se[Treatment], _b[Treatment]-invt(e(df_r), .975)*_se[Treatment] ///
	        , _b[Treatment ]+ invt(e(df_r), .975)*_se[Treatment] , `p_value')
        }
    }
	
    matrix ols_analysis_$AnalysisYear = analysis_means, analysis_ols

	** Reformat table
	use "$ext/Analysis Data/temp/analysis_data_loaded", clear
   
    * No weights
    foreach outcome in $Outcomes {
        summ `outcome' if Control == 1
        matrix analysis_means_long = nullmat(analysis_means_long) \ (`r(mean)' \ `r(sd)' \ . )
	    
    }	
    foreach outcome in $Outcomes {
        if "`outcome'" == "cqs" {
            reg `outcome' Treatment _strata*, r
            local p_value = 2 * ttail(e(df_r), abs(_b[Treatment]/_se[Treatment]))
            matrix analysis_ols_long = nullmat(analysis_ols_long) \ ///
                (_b[Treatment] \ _se[Treatment] \  `p_value')
        }
        else {
            reg `outcome' Treatment _strata* `outcome'_2013 `outcome'_2014, r
            local p_value = 2 * ttail(e(df_r), abs(_b[Treatment]/_se[Treatment]))
            matrix analysis_ols_long = nullmat(analysis_ols_long) \ ///
                (_b[Treatment] \ _se[Treatment] \ `p_value')
        }
    }
	
	* Weighted
    foreach outcome in $Outcomes {
        summ `outcome' [aw=num_epsd_post] if Control == 1
        matrix analysis_means_w_long = nullmat(analysis_means_w_long) \ (`r(mean)' \ `r(sd)' \ . )
    }	
    foreach outcome in $Outcomes {
        if "`outcome'" == "cqs" {
            reg `outcome' Treatment _strata* [aw = num_epsd_post], r
            local p_value = 2 * ttail(e(df_r), abs(_b[Treatment]/_se[Treatment]))
            matrix analysis_ols_w_long = nullmat(analysis_ols_w_long) \ ///
                (_b[Treatment] \ _se[Treatment] \  `p_value')
        }
        else {
            reg `outcome' Treatment _strata* `outcome'_2013 `outcome'_2014 [aw = num_epsd_post], r
            local p_value = 2 * ttail(e(df_r), abs(_b[Treatment]/_se[Treatment]))
            matrix analysis_ols_w_long = nullmat(analysis_ols_w_long) \ ///
                (_b[Treatment] \ _se[Treatment] \  `p_value')
        }
    }
    matrix ols_analysis_long$AnalysisYear = analysis_means_long, analysis_ols_long
    matrix ols_analysis_w_long$AnalysisYear = analysis_means_w_long, analysis_ols_w_long
		
end


program make_tables
   
    foreach mat in ols_analysis_$AnalysisYear {
        clear
        svmat `mat'
        label variable `mat'1 "Mean Value in Control Group"
        label variable `mat'2 "SD"
        label variable `mat'3 "Change with Bundled Payment"
		label variable `mat'4 "SE"
        label variable `mat'5 "95% CI Lower Bound"
        label variable `mat'6 "95% CI Upper Bound"
        label variable `mat'7 "P-Value"

        gen varname = "Claims" in 1
        replace varname = "Claims for Index Admission" in 2
        replace varname = "Claims for Institutional PAC" in 3
        replace varname = "Claims for Home Health" in 4
        replace varname = "Other Claims" in 5
	    replace varname = "Number of Days in Index Admission" in 6
        replace varname = "Number of Days in Institutional PAC" in 7
        replace varname = "Share Discharged to Institutional Post Acute Care" in 8
        replace varname = "Share Discharged to Home Health Agency" in 9
        replace varname = "Share Discharged Home (w/o Home Health Agency)" in 10
        replace varname = "Share Discharged to Other" in 11
		replace varname = "Government Spending" in 12
        replace varname = "Complication Rate" in 13
        replace varname = "ER Visit During Episode" in 14
        replace varname = "90-day All Cause Readmission Rate" in 15
        replace varname = "LEJR Admissions (per 1,000 enrollees)" in 16
        replace varname = "CJR-eligible LEJR Admissions (per 1,000 enrollees)" in 17
        replace varname = "Elixhauser Comorbidity Score" in 18
	
        order varname, first
        export excel using "../output/tables/Table1", ///
            sheet("`mat'") firstrow(varlabels) sheetreplace
    }
	
    foreach mat in ols_analysis_long$AnalysisYear ols_analysis_w_long$AnalysisYear {
        clear
        svmat `mat'
        label variable `mat'1 "Control Mean (SD)"
        label variable `mat'2 "Average Treatment Effect (SE) (P-Value)"

        gen varname = "Claims" in 1
        replace varname = "Claims for Index Admission" in 4
        replace varname = "Claims for Institutional PAC" in 7
        replace varname = "Claims for Home Health" in 10
        replace varname = "Other Claims" in 13
	    replace varname = "Number of Days in Index Admission" in 16
        replace varname = "Number of Days in Institutional PAC" in 19
        replace varname = "Share Discharged to Institutional Post Acute Care" in 22
        replace varname = "Share Discharged to Home Health Agency" in 25
        replace varname = "Share Discharged Home (w/o Home Health Agency)" in 28
        replace varname = "Share Discharged to Other" in 31
		replace varname = "Government Spending" in 34
        replace varname = "Complication Rate" in 37
        replace varname = "ER Visit During Episode" in 40
        replace varname = "90-day All Cause Readmission Rate" in 43
        replace varname = "LEJR Admissions (per 1,000 enrollees)" in 46
        replace varname = "CJR-eligible LEJR Admissions (per 1,000 enrollees)" in 49
        replace varname = "Elixhauser Comorbidity Score" in 52
	
        order varname, first
        export excel using "../output/tables/TableA2_Panels_1_2", ///
            sheet("`mat'") firstrow(varlabels) sheetreplace
    }
end

* Execute
main
