version 15
set more off
preliminaries, seed(02138)

global ext = "[EXT DIR]"
global data_dir = "[DATA DIR]"

global Outcomes = "tot_spend inst_pac_spend dschrg_inst_pac"

program main

    load_data
	levels_table
    bivariate_regs
	
end


program load_data

    use "$ext/Episode Level Data/output/all_episode_level_data2013.dta", clear
	append using "$ext/Episode Level Data/output/all_episode_level_data2014.dta"
	keep if Final_MSA == 1 & cjr_sample == 1
    merge m:1 provider using  "$ext/Analysis Data/output/provider_level_data2016_2017.dta", ///
        keep(3) keepusing(mandatory num_epsd_pre num_epsd_post) nogen
		
	* Keep only providers from the baseline
    merge m:1 provider using "$ext/Analysis Data/output/provider_level_data_baseline", ///
        keep(3) keepusing(provider) nogen
		
    gen voluntary = mandatory == 0
    rename DRG_CD drg_cd
	rename BENE_ID bene_id
	gen inst_pac_oop = irf_oop + ltch_oop + snf_oop
	foreach type in inst_pac tot {
	    gen `type'_spend = `type'_pay + `type'_oop
	}
	
    merge m:1 provider using "$ext/AHA/output/aha", assert(1 2 3) ///
        keep(1 3) nogen
	    
    * Merge with CQS
    destring provider, replace
    merge m:1 provider using "$ext/CQS/output/quality_measures.dta", ///
        assert(1 2 3) keep(1 3) keepusing(cqs) nogen
		
	* Merge with Elixhauser
    merge m:1 episode_id using "$ext/Elixhauser/output/elix2014.dta", ///
        assert(1 2 3) keep(1 3) keepusing(elixsum) nogen
	rename elixsum elixsum_2014
    merge m:1 episode_id using "$ext/Elixhauser/output/elix2013.dta", ///
        assert(1 2 3) keep(1 3) keepusing(elixsum) nogen
	replace elixsum = elixsum_2014 if elixsum == .
	drop elixsum_2014
    qui summ bene_age, det
	local mincut = `r(min)' - 1
	local maxcut = `r(max)' + 1
    egen age_bins = cut(bene_age), at(`mincut' 55 60 65 70 75 80 85 90 `maxcut')
    destring bene_race, replace
    gen female = (bene_sex == "2")
	gen white = (bene_race == 1)
    egen age_race_sex = group(age_bins white female)
    gen major_comps = (drg_cd == "469")
    gen disabled = (bene_orec == "1"|bene_orec == "3")
    gen ownership = 1 if prov_fp == 1
	replace ownership = 2 if prov_np == 1
	replace ownership = 3 if ownership == .
    save "../temp/data_loaded", replace

end

program levels_table
    * Table A5
    local hosp_chars num_epsd_pre cqs prov_beds prov_coth i.ownership i.strata i.msa
  
    local counter = 0
    foreach outcome in $Outcomes {
      use ../temp/data_loaded, clear	
      local counter = `counter' + 1
      
	  fe_sd, y(`outcome') fe(0) x("") ///
           matname(hosp_hosp_fe_sds`counter') counter(`counter')
	  
      foreach var in `hosp_chars' {
	  if "`var'" == "i.msa" {
              fe_sd, y(`outcome') matname(hosp_hosp_fe_sds`counter') ///
	        absorb(`var') fe(1) counter(`counter')
          }
	  if "`var'" != "i.msa" {
              fe_sd, y(`outcome') matname(hosp_hosp_fe_sds`counter') ///
	        x(`var') fe(0) counter(`counter')
	  }
      }
 
      fe_sd, y(`outcome') matname(hosp_hosp_fe_sds`counter') ///
        x("num_epsd_pre cqs prov_beds i.ownership prov_coth") absorb(msa) fe(1) ///
	counter(`counter')
      fe_sd, y(`outcome') matname(hosp_hosp_fe_sds`counter') counter(`counter') ///
        x("num_epsd_pre cqs prov_beds i.ownership prov_coth i.age_race_sex disabled major_comps elixsum hip_fracture_flag") ///
	    absorb(msa) fe(1)	
  }
  
    matrix hospchars_fe_sd = hosp_hosp_fe_sds1 \ hosp_hosp_fe_sds2 \ hosp_hosp_fe_sds3 \ hosp_hosp_fe_sds1_n
		
end

program fe_sd 
  syntax, y(str) matname(str) fe(int) counter(int) [absorb(str) x(str)] 
  if `fe' == 1 qui reghdfe `y' `x', absorb(`absorb', savefe)
  if `fe' == 0 qui reg `y' `x', robust
  predict resid, residuals
  qui reghdfe resid, absorb(hosp_fe = provider)
  collapse (mean) hosp_fe num_epsd_post, by(provider) 
  qui sum hosp_fe [aw = num_epsd_post], d
  local stdev = r(sd)
  local num_hosp = r(N)
  matrix `matname' = nullmat(`matname') , `stdev'
  if `counter' == 1 matrix `matname'_n = nullmat(`matname'_n) , `num_hosp'
  use ../temp/data_loaded, clear
end

program bivariate_regs
    * Table 2
    use ../temp/data_loaded, clear
    collapse (mean) $Outcomes num_epsd_pre cqs prov_beds prov_fp prov_np prov_coth num_epsd_post, by(provider) 
    foreach outcome in $Outcomes {
		summ `outcome' [aw = num_epsd_post]
		matrix biv_level_`outcome'  = nullmat(biv_level_`outcome') \ (`r(mean)', `r(sd)')
		foreach xvar in num_epsd_pre cqs prov_beds prov_coth {
		    reg `outcome' `xvar' [aw=num_epsd_post], robust
			matrix biv_level_`outcome'  = nullmat(biv_level_`outcome') \ ( _b[`xvar'], _se[`xvar'])
		}
		reg `outcome' prov_fp prov_np [aw=num_epsd_post], robust
			matrix biv_level_`outcome' = nullmat(biv_level_`outcome') \ (_b[prov_fp], _se[prov_fp])
			matrix biv_level_`outcome' = nullmat(biv_level_`outcome') \ (_b[prov_np], _se[prov_np])
	}
	matrix biv_levels = biv_level_tot_spend, biv_level_inst_pac_spend, biv_level_dschrg_inst_pac
    mat list biv_levels
end

* Execute
main
