version 15
preliminaries

global data_dir = "[DATA DIR]"
global ext = "[EXT DIR]"

global Outcomes = "tot_spend inst_pac_spend dschrg_inst_pac"

program main
    gen_pre_post_data
    distribution_of_y_pre
    make_table
end

program gen_pre_post_data

    use if mandatory == 0 using "$ext/Analysis Data/output/provider_level_data_baseline.dta", clear
   
    foreach var in $Outcomes {
	gen delta_`var' = `var'_post - `var'_pre
    }
    	
    save "${data_dir}/temp/voluntary_treatment_pre_post", replace

end

program distribution_of_y_pre

    use "${data_dir}/temp/voluntary_treatment_pre_post", clear
		
    foreach var in $Outcomes  {
        foreach group in Control Select_In Select_Out {
	        qui: sum `var'_pre [aw = num_epsd_post] if `group' == 1, det
	        mat y_pre_tmp = nullmat(y_pre_tmp) , (`r(mean)' \ `r(sd)')
		}
		mat y_pre_w = nullmat(y_pre_w) \ y_pre_tmp
		reg `var'_pre Select_In if Treatment == 1 [aw = num_epsd_post], r
        local p_val_r = 2 * ttail(e(df_r), abs(_b[Select_In]/_se[Select_In]))
		reg `var'_pre Select_In if Treatment == 1 [aw = num_epsd_post]
        local p_value = 2 * ttail(e(df_r), abs(_b[Select_In]/_se[Select_In]))
		mat y_pre_p_w = nullmat(y_pre_p_w) \ ((`p_value', `p_val_r') \ (. , .))
		mat drop y_pre_tmp
    }
	
	foreach group in Select_In Select_Out  {
	    qui: sum tot_net_of_target_pre [aw = num_epsd_post] if `group' == 1, det
	    mat y_pre_tmp = nullmat(y_pre_tmp) , (`r(mean)' \ `r(sd)')
    }
	mat y_pre_w = y_pre_w \ ( (. \ .), y_pre_tmp)
    reg tot_net_of_target_pre Select_In if Treatment == 1 [aw = num_epsd_post], r
    local p_val_r = 2 * ttail(e(df_r), abs(_b[Select_In]/_se[Select_In]))  
	reg tot_net_of_target_pre Select_In if Treatment == 1 [aw = num_epsd_post]
    local p_value = 2 * ttail(e(df_r), abs(_b[Select_In]/_se[Select_In]))
	mat y_pre_p_w = y_pre_p_w \ ((`p_value', `p_val_r') \ (. , .))
	mat drop y_pre_tmp
	
	mat y_pre_w = (y_pre_w, y_pre_p_w) \ (. , `num_epsdA', `num_epsdB', . , .)

end

program make_table
	
	foreach mat in y_pre_w {
    mat colnames  `mat' = Voluntary_Control Select_In Select_Out P_Value P_Value_Robust
    clear 
    svmat  `mat', names(col)
    gen varname = "Total Episode Spending" in 1
	replace varname = "Episode Spending in Instituitional Post Acute Care" in 3
	replace varname = "Share Discharged to Instituitional Post Acute Care" in 5
	replace varname = "Total Episode Spending Minus Target" in 7
	replace varname = "Number of Episodes in Pre Period" in 9
	replace varname = "S.D." if inlist(_n, 2, 4, 6, 8)
	order varname, first
	
	export excel using "../output/tables/Table3P1", ///
            sheet(" `mat'") firstrow(varlabels) sheetreplace
			
   }
end

* Execute
main
