version 15
set more off
adopath + ../external/lib/stata/gslab_misc/ado
adopath + ../external/lib/stata
adopath + .

preliminaries

global data_dir = "[DATA DIR]"
global ext = "[EXT DIR]"

global Outcomes = "tot_spend inst_pac_spend dschrg_inst_pac"

program main

    load_data
    hospital_level_ols_msa_cluster
    make_table
    
end

program load_data

    use "$ext/Analysis Data/output/provider_level_data_baseline.dta", clear
  
    * Generate interactions of Treatment dummy and hospital dummies
    
    sort mandatory Select_In Select_Out provider
    bys mandatory Select_In Select_Out: gen Num = _n 
    
    sum Num if Select_In ==1 & mandatory ==0
    
    forv i = 1/`r(max)' {
        gen In_Treat_`i' = (Num == `i' & Select_In ==1 & mandatory ==0)
    }

    sum Num if Select_Out ==1 & mandatory ==0
    
    forv i = 1/`r(max)' {
        gen Out_Treat_`i' = (Num == `i' & Select_Out ==1 & mandatory ==0)
    }
    
	sort mandatory Treatment provider
	by mandatory Treatment: gen Num2 = _n if mandatory == 1 & Treatment == 1 

    sum Num2 
    
    forv i = 1/`r(max)' {
        gen Man_Treat_`i' = (Num2 == `i' & mandatory ==1  & Treatment == 1)
    } 
		
    save "${data_dir}/temp/data_loaded_pre_post", replace
		
end

program hospital_level_ols_msa_cluster
		    
    foreach outcome in $Outcomes {
	
        use "${data_dir}/temp/data_loaded_pre_post", clear
	
		* Weighted

		reg `outcome'_post In_Treat* Out_Treat* Man_Treat* i.strata ///
			`outcome'_2013 `outcome'_2014 [aw = num_epsd_post], vce(cluster msa)
		
		qui: sum Num if Select_In ==1 & mandatory ==0
		local max = `r(max)'
		
		forv i = 1/`max' {
			qui: sum `outcome'_pre if In_Treat_`i'==1
			local pre_level = `r(mean)'
			qui: sum num_epsd_post if In_Treat_`i'==1
			local num_epsd_post = `r(mean)'
			qui: sum num_bene_post if In_Treat_`i'==1
			local num_bene_post = `r(mean)'
			summ msa if In_Treat_`i'==1 
			local msa = `r(mean)'
			mat In_Treat_`outcome' = nullmat(In_Treat_`outcome') \ ///
			    (_b[In_Treat_`i'], `pre_level', `num_epsd_post', `num_bene_post', 1, `msa')
		}

		qui: sum Num if Select_Out ==1 & mandatory ==0
		local max = `r(max)'

		forv i = 1/`max' {
			qui: sum `outcome'_pre if Out_Treat_`i'==1
			local pre_level = `r(mean)'
			qui: sum num_epsd_post if Out_Treat_`i'==1
			local num_epsd_post = `r(mean)'
			qui: sum num_bene_post if Out_Treat_`i'==1
			local num_bene_post = `r(mean)'
			summ msa if Out_Treat_`i'==1 
			local msa = `r(mean)'
			mat Out_Treat_`outcome' = nullmat(Out_Treat_`outcome') \ ///
			    (_b[Out_Treat_`i'], `pre_level', `num_epsd_post', `num_bene_post', 0, `msa')
		}
		
		qui: sum Num2 if mandatory == 1 & Treatment == 1
		local max = `r(max)'

		forv i = 1/`max' {
			qui: sum `outcome'_pre if Man_Treat_`i'==1
			local pre_level = `r(mean)'
			qui: sum num_epsd_post if Man_Treat_`i'==1
			local num_epsd_post = `r(mean)'
			qui: sum num_bene_post if Man_Treat_`i'==1
			local num_bene_post = `r(mean)'
			summ msa if Man_Treat_`i'==1 
			local msa = `r(mean)'
			mat Man_Treat_`outcome' = nullmat(Man_Treat_`outcome') \ ///
			    (_b[Man_Treat_`i'], `pre_level', `num_epsd_post', `num_bene_post', 0, `msa')
		}
    
   
    matrix In_Out_Treat_`outcome' = In_Treat_`outcome' \ Out_Treat_`outcome'
    matrix Hospital_Treat_`outcome' = In_Treat_`outcome' \ Out_Treat_`outcome' \ Man_Treat_`outcome'
    
    mat colnames In_Out_Treat_`outcome' = beta pre_level num_epsd_post num_bene_post selection msa
    
    clear
    
    svmat In_Out_Treat_`outcome', names(col)
    
    save "${data_dir}/temp/regression_estimates_`outcome'.dta", replace
	
	}
		
    * Weighted	
	foreach outcome in $Outcomes{
        use  "${data_dir}/temp/regression_estimates_`outcome'.dta", clear
	    summ beta [aw = num_epsd_post] if selection == 1
	    mat summ_treat_ww_`outcome' = nullmat(summ_treat_ww_`outcome') , (`r(mean)' \ `r(sd)')
	    summ beta [aw = num_epsd_post] if selection == 0
	    mat summ_treat_ww_`outcome' = nullmat(summ_treat_ww_`outcome') , (`r(mean)' \ `r(sd)')

	    reg beta selection [aw = num_epsd_post], r
	    local p_val_r = 2 * ttail(e(df_r), abs(_b[selection]/_se[selection]))

	    reg beta selection [aw = num_epsd_post]
	    local p_val = 2 * ttail(e(df_r), abs(_b[selection]/_se[selection]))

	    mat summ_treat_ww_`outcome' = nullmat(summ_treat_ww_`outcome') , ((`p_val', `p_val_r') \ (. , .) )
    }
	mat summ_treatment_ww = summ_treat_ww_tot_spend \ ///
	    summ_treat_ww_inst_pac_spend \ summ_treat_ww_dschrg_inst_pac
 		
end


program make_table


    foreach mat in summ_treatment_ww {
        clear
        svmat `mat'
        label variable `mat'1 "Mean among Hospital Selected In"
        label variable `mat'2 "Mean among Hospital Selected Out"
        label variable `mat'3 "P-Value of Difference in Means"
        label variable `mat'4 "P-Value of Difference in Means (Robust)"

        gen varname = "Change in Total Episode Spending" in 1
        replace varname = "Change in Institutional PAC Spending" in 3
        replace varname = "Change in Share Discharged to Institutional PAC" in 5
	    
		gen rows = "Mean of Estimates" if inlist(_n, 1, 3, 5, 7)
        replace rows = "S.D. of Estimates" if inlist(_n, 2, 4, 6, 8)
		
        order varname rows, first
        export excel using "../output/tables/Table3P2", ///
            sheet("`mat'") firstrow(varlabels) sheetreplace
    }
    
end

* Execute
main
