version 15
set more off

preliminaries, seed(02138)
global ext = "[EXT DIR]"
global data_dir = "[DATA DIR]"
global Outcomes = "prov_meanepsd prov_beds prov_coth"
global Outcomes = "$Outcomes prov_fp prov_np prov_govt cqs"

program main

    load_data
    summary_stats
    make_table
    
end

program load_data

    use "$ext/Analysis Data/output/provider_level_data2016_2017.dta", clear
	* Keep only providers from the baseline
    merge m:1 provider using "$ext/Analysis Data/output/provider_level_data_baseline", ///
        keep(3) keepusing(provider) nogen
		
    gen voluntary = mandatory == 0
    
    merge 1:1 provider using "$ext/AHA/output/aha", assert(1 2 3) ///
        keep(1 3) nogen
	
    gen prov_meanepsd = num_epsd_pre
    
    destring provider, replace
    merge 1:1 provider using "$ext/CQS/output/cjr_official_quality.dta", ///
        keep(1 3) keepusing(cqs_official) nogen
    merge 1:1 provider using "$ext/CQS/output/quality_measures.dta", ///
        keep(1 3) keepusing(cqs) nogen
    
    bys Select_In Select_Out: egen tot_epsd_pre = total(num_epsd_pre) if voluntary == 1
 
    gen tau = ln(target)
    gen lambda_pre = ln(tot_spend_pre)
    save "../temp/data_loaded", replace

end

program summary_stats

    use if mandatory == 0 using "../temp/data_loaded", clear
	    
    foreach outcome in $Outcomes {
        summ `outcome' [aw = num_epsd_post] if Select_In == 1 & Treatment == 1
	    local mean_in = `r(mean)'
	    summ `outcome' [aw = num_epsd_post] if Select_Out == 1 & Treatment == 1
	    local mean_out = `r(mean)'
	    summ `outcome' [aw = num_epsd_post] if Treatment == 0
	    local mean_control = `r(mean)'
	    reg `outcome' Select_In [aw = num_epsd_post] if Treatment == 1, r
	    local p_val_r = 2 * ttail(e(df_r), abs(_b[Select_In]/_se[Select_In]))
	    reg `outcome' Select_In [aw = num_epsd_post] if Treatment == 1
	    local p_val = 2 * ttail(e(df_r), abs(_b[Select_In]/_se[Select_In]))
	    mat select_in_summ_stats_w = nullmat(select_in_summ_stats_w) \ ///
	        (`mean_control', `mean_in', `mean_out', `p_val', `p_val_r')
    }
    
    count if Select_In == 1
    local N_in = `r(N)'
    count if Select_Out == 1
    local N_out = `r(N)'
    count if Treatment == 0
    local N_control = `r(N)'
    mat select_in_summ_stats_w = nullmat(select_in_summ_stats_w) \ ( `N_control', `N_in', `N_out' , ., .)


end

program make_table


    use "$ext/Analysis Data/output/episode_level_data2016_2017.dta", clear
	* Keep only providers from the baseline
    merge m:1 provider using "$ext/Analysis Data/output/provider_level_data_baseline", ///
        keep(3) keepusing(provider) nogen
	egen num_bene_temp = tag(bene_id)
    egen total = total(num_bene_temp)

    foreach mat in select_in_summ_stats_w {
            clear
	    svmat `mat'
	    label variable `mat'1 "Voluntary Control Hospitals"
	    label variable `mat'2 "Select-In Hospitals"
	    label variable `mat'3 "Select-Out Hospitals"
	    label variable `mat'4 "P-Value of Difference"
	    label variable `mat'5 "P-Value of Difference (Robust)"
	    
		gen varname = "Average Number of CJR Episodes" in 1
	    replace varname = "Mean Number of Beds" in 2
	    replace varname = "Share Teaching" in 3
        replace varname = "Share For-profit" in 4
	    replace varname = "Share Non-profit" in 5
	    replace varname = "Share Government-owned" in 6
	    replace varname = "Mean Quality" in 7
	    replace varname = "Number of Hospitals" in 8
	    
	    order varname, first
	    	    
	    export excel using "../output/tables/Table3P3", ///
		sheet("`mat'") firstrow(varlabels) sheetreplace
    }
    
end

* Execute
main
