version 16
set more off

global est_dir = "[EST DIR]"
global data_dir = "[DATA DIR]"
global Outcomes = "elix_change_20162017_20132014 elix_change_2018_20132014 elix_change_2018_20162017"

program main

    load_elix
	elix_changes, year1(2012) year2(2013)
	elix_changes, year1(2013) year2(2014)
	elix_changes, year1(20132014) year2(20162017)
	elix_changes, year1(20132014) year2(2018)
	elix_changes, year1(20162017) year2(2018)
	elix_change_opt_in
    make_tables
	
end

program load_elix

    foreach year in 2012 2013 2014 {
        use if cjr_sample == 1 & Final_MSAs == 1 using ///
            "../external_links/episode_all/all_episode_level_data`year'.dta", clear
		merge m:1 provider using "../external_links/episode/provider_level_data2016_2017.dta", ///
		    keep(2 3) nogen keepusing(provider) // keep just the baseline sample
		merge m:1 episode_id using "../external_links/elix/elix`year'.dta", ///
		    keep(3) keepusing(elixsum) nogen
		save "${data_dir}/temp/episode_level_elixsum_`year'", replace

        collapse (mean) elixsum, by(provider msa)
		rename elixsum elixsum_`year'
        save "${data_dir}/temp/elixsum_`year'", replace
    }
	
	use "${data_dir}/temp/episode_level_elixsum_2013", clear
	append using "${data_dir}/temp/episode_level_elixsum_2014"
	collapse (mean) elixsum, by(provider msa)
	rename elixsum elixsum_20132014

    save "${data_dir}/temp/elixsum_20132014", replace
	
	use msa mandatory using "../external_links/episode/provider_level_data2016_2017.dta", clear
	duplicates drop
    save "${data_dir}/temp/mandatory_msas", replace
	
	use if cjr_sample == 1 & Final_MSAs == 1 using ///
		"../external_links/episode/episode_level_data2016_2017.dta", clear
	merge m:1 msa using "${data_dir}/temp/mandatory_msas", assert(3) nogen
	merge m:1 episode_id using "../external_links/elix/elix2016_2017.dta", ///
		keep(3) keepusing(elixsum) nogen

	collapse (mean) elixsum, by(provider msa)
	rename elixsum elixsum_20162017
	save "${data_dir}/temp/elixsum_20162017", replace
	
	use if cjr_sample == 1 & Final_MSAs == 1 using ///
		"../external_links/episode/episode_level_data2016_2018.dta", clear
	merge m:1 msa using "${data_dir}/temp/mandatory_msas", assert(3) nogen
	merge m:1 episode_id using "../external_links/elix/elix2016_2018.dta", ///
		keep(3) keepusing(elixsum) nogen
    keep if year(admsn_dt) == 2018 

	collapse (mean) elixsum, by(provider msa)
	rename elixsum elixsum_2018
	save "${data_dir}/temp/elixsum_2018", replace
end

program elix_changes
    syntax, year1(str) year2(str)

    use "${data_dir}/temp/elixsum_`year2'", clear
    merge 1:1 provider using "${data_dir}/temp/elixsum_`year1'", nogen

    replace elixsum_`year2' = 0 if elixsum_`year2' == .
    replace elixsum_`year1' = 0 if elixsum_`year1' == .
    gen elix_change_`year2'_`year1' = abs(elixsum_`year2'- elixsum_`year1')
    
    save "${data_dir}/temp/elixsum_`year2'_`year1'", replace

    use "${data_dir}/temp/elixsum_`year2'", clear
    merge 1:1 provider using "${data_dir}/temp/elixsum_`year1'", nogen

    replace elixsum_`year2' = 0 if elixsum_`year2' == .
    replace elixsum_`year1' = 0 if elixsum_`year1' == .
    gen elix_change_`year2'_`year1' = elixsum_`year2'- elixsum_`year1'
    
    save "${data_dir}/temp/elix_change_`year2'_`year1'", replace
end

program elix_change_opt_in

    ** Look within voluntary treatment, see changes in elix by selecting in
    use "../external_links/episode/provider_level_data2016_2018.dta", clear
	keep if mandatory == 0 & Treatment == 1

    foreach file in 2014_2013 20162017_20132014 2018_20132014 2018_20162017 {
    	merge 1:1 provider using "${data_dir}/temp/elixsum_`file'", ///
	    keep(1 3) nogen
    }
	
	summ elixsum_2018 if Select_Out == 1
    matrix select_in_elix_means = nullmat(select_in_elix_means) \ (`r(mean)' , `r(sd)')
	
	areg elixsum_2018 Select_In elixsum_20132014, a(msa) vce(cluster msa)	
    local p_value = 2 * ttail(e(df_r), abs(_b[Select_In]/_se[Select_In]))
    matrix select_in_elix = nullmat(select_in_elix) \ ///
            (_b[Select_In] , _se[Select_In], _b[Select_In]-invt(e(df_r), .975)*_se[Select_In] ///
	    , _b[Select_In ]+ invt(e(df_r), .975)*_se[Select_In] , `p_value')
		
	areg elixsum_2018 Select_In elixsum_20162017, a(msa) vce(cluster msa)	
    local p_value = 2 * ttail(e(df_r), abs(_b[Select_In]/_se[Select_In]))
    matrix select_in_elix = nullmat(select_in_elix) \ ///
            (_b[Select_In] , _se[Select_In], _b[Select_In]-invt(e(df_r), .975)*_se[Select_In] ///
	    , _b[Select_In ]+ invt(e(df_r), .975)*_se[Select_In] , `p_value')
		
	areg elixsum_2018 Select_In elixsum_20132014 elixsum_20162017, a(msa) vce(cluster msa)
    local p_value = 2 * ttail(e(df_r), abs(_b[Select_In]/_se[Select_In]))
    matrix select_in_elix = nullmat(select_in_elix) \ ///
            (_b[Select_In] , _se[Select_In], _b[Select_In]-invt(e(df_r), .975)*_se[Select_In] ///
	    , _b[Select_In ]+ invt(e(df_r), .975)*_se[Select_In] , `p_value')

	mat select_in_elix = (select_in_elix_means \ (.,.) \ (.,.) ), select_in_elix
		
end


program make_tables
	
    foreach mat in select_in_elix {
        clear
        svmat `mat'
        label variable `mat'1 "Mean Value in Control Group"
        label variable `mat'2 "SD"
        label variable `mat'3 "Change with Bundled Payment"
		label variable `mat'4 "S.E."
        label variable `mat'5 "95% CI Lower Bound"
        label variable `mat'6 "95% CI Upper Bound"
        label variable `mat'7 "P-Value"

        gen y_var = "Elixhauser in 2018" in 1
        replace y_var = "Elixhauser in 2018" in 2
        replace y_var = "Elixhauser in 2018" in 3

		gen covariate = "Elixhauser in 2013-2014" in 1
        replace covariate = "Elixhauser in 2016-2017" in 2
        replace covariate = "Elixhauser in 2013-2014, 2016-2017" in 3
		
        order y_var covariate, first
		
        export excel using "../output/tables/TableA1P1", ///
            sheet("`mat'") firstrow(varlabels) sheetreplace
    }
	

end

* Execute
main
