version 16
set more off

global data_dir = "[DATA DIR]"
global est_dir = "[EST DIR]"
global ext = "[EXT DIR]"


program main

    load_num_epsd
    volume_changes, year1(2012) year2(2013)
    volume_changes, year1(2013) year2(2014)
    volume_changes, year1(20132014) year2(20162017)
    volume_changes, year1(20132014) year2(2018)
    volume_changes, year1(20162017) year2(2018)	
	epsd_change_opt_in
    make_tables
	
end

program load_num_epsd

    foreach year in 2012 2013 2014 {
        use if cjr_sample == 1 & Final_MSAs == 1 using ///
            "$ext/Episode Level Data/output/all_episode_level_data`year'.dta", clear
		merge m:1 provider using "$ext/Analysis Data/output/provider_level_data2016_2017.dta", ///
		    keep(2 3) nogen keepusing(provider) // keep just the baseline sample
        gen  num_epsd_`year' = 1
        collapse (sum) num_epsd_`year', by(provider msa)
	    bys msa: egen total_mkt_epsd = total(num_epsd_`year')
	    gen mkt_share_`year' = num_epsd_`year'/total_mkt_epsd
        save "${data_dir}/temp/num_epsd_`year'", replace
    }
        use msa mandatory using "$ext/Analysis Data/output/provider_level_data2016_2017.dta", clear
		duplicates drop
        save "${data_dir}/temp/mandatory_msas", replace
		
    use if cjr_sample == 1 & Final_MSAs == 1 using ///
        "$ext/Episode Level Data/output/all_episode_level_data2016_2017.dta", clear
    gen  num_epsd_2016 = 1
	merge m:1 msa using "${data_dir}/temp/mandatory_msas", assert(3) nogen

    * keep only Apr 1 to Sept 15 to be consistent with other years
    keep if year(admsn_dt) == 2016 & ///
        (month(admsn_dt) < 9 | (month(admsn_dt) == 9 & day(admsn_dt) <= 15))
    egen num_bene = tag(BENE_ID)
    collapse (sum) num_epsd_2016 num_bene, by(provider Control mandatory)
    	
    save "${data_dir}/temp/num_epsd_2016", replace
    
    use if cjr_sample == 1 & Final_MSAs == 1 using ///
        "$ext/Episode Level Data/output/all_episode_level_data2016_2017.dta", clear
    gen  num_epsd_2017 = 1
	merge m:1 msa using "${data_dir}/temp/mandatory_msas", assert(3) nogen

    * keep only Apr 1 to Sept 15 to be consistent with other years
    keep if year(admsn_dt) == 2017 & month(admsn_dt) >= 4
	egen num_bene = tag(BENE_ID)
    collapse (sum) num_epsd_2017 num_bene, by(provider Control mandatory)
    save "${data_dir}/temp/num_epsd_2017", replace
	
	use "$ext/Episode Level Data/output/all_episode_level_data2013.dta", clear
	append using "$ext/Episode Level Data/output/all_episode_level_data2014.dta"
	keep if cjr_sample == 1 & Final_MSAs == 1
    gen  num_epsd_20132014 = 1
	merge m:1 provider using "$ext/Analysis Data/output/provider_level_data2016_2017.dta", ///
		    keep(2 3) nogen keepusing(provider) // keep just the baseline sample
	merge m:1 msa using "${data_dir}/temp/mandatory_msas", assert(3) nogen
    collapse (sum) num_epsd_20132014, by(provider Control mandatory msa)
    	bys msa: egen total_mkt_epsd = total(num_epsd_20132014)
	gen mkt_share_20132014 = num_epsd_20132014/total_mkt_epsd
	
    save "${data_dir}/temp/mkt_share_20132014", replace
	
    use if cjr_sample == 1 & Final_MSAs == 1 using ///
        "$ext/Analysis Data/output/episode_level_data2016_2017.dta", clear
    gen  num_epsd_20162017 = 1
	merge m:1 msa using "${data_dir}/temp/mandatory_msas", assert(3) nogen
    collapse (sum) num_epsd_20162017, by(provider Control mandatory msa)
    	bys msa: egen total_mkt_epsd = total(num_epsd_20162017)
	gen mkt_share_20162017 = num_epsd_20162017/total_mkt_epsd
	
    save "${data_dir}/temp/mkt_share_20162017", replace
	
	use if cjr_sample == 1 & Final_MSAs == 1 using ///
        "$ext/Analysis Data/output/episode_level_data2016_2018.dta", clear
    gen  num_epsd_2018 = 1
    keep if year(admsn_dt) == 2018 
	merge m:1 msa using "${data_dir}/temp/mandatory_msas", assert(3) nogen
    collapse (sum) num_epsd_2018, by(provider Control mandatory msa)
    bys msa: egen total_mkt_epsd = total(num_epsd_2018)
	gen mkt_share_2018= num_epsd_2018/total_mkt_epsd
	
    save "${data_dir}/temp/mkt_share_2018", replace
		
    use if cjr_sample == 1 & Final_MSAs == 1 using ///
        "$ext/Analysis Data/output/episode_level_data2016_2018.dta", clear
    gen  num_epsd_2018 = 1
	merge m:1 msa using "${data_dir}/temp/mandatory_msas", assert(3) nogen
    * keep only Apr 1 to Sept 15 to be consistent with other years
    keep if year(admsn_dt) == 2018 & month(admsn_dt) >= 4
	egen num_bene = tag(bene_id)
    collapse (sum) num_epsd_2018 num_bene, by(provider Control mandatory msa)
	merge m:1 provider using "${data_dir}/temp/mkt_share_2018", assert(1 2 3) keep(2 3) nogen
    save "${data_dir}/temp/num_epsd_2018", replace
    
    use "${data_dir}/temp/num_epsd_2017", clear
    replace num_epsd_2017 = 0 if num_epsd_2017 == .
    rename num_epsd_2017 num_epsd_2016
    append using "${data_dir}/temp/num_epsd_2016"
    replace num_epsd_2016 = 0 if num_epsd_2016 == .
    rename num_epsd_2016 num_epsd_20162017
    collapse (mean) num_epsd_20162017, by(provider)
    merge m:1 provider using "${data_dir}/temp/mkt_share_20162017", assert(1 3) keep(3) nogen
    save "${data_dir}/temp/num_epsd_20162017", replace
	
	use "${data_dir}/temp/num_epsd_2014", clear
    replace num_epsd_2014 = 0 if num_epsd_2014 == .
    rename num_epsd_2014 num_epsd_2013
    append using "${data_dir}/temp/num_epsd_2013"
    replace num_epsd_2013 = 0 if num_epsd_2013 == .
    rename num_epsd_2013 num_epsd_20132014
    collapse (mean) num_epsd_20132014, by(provider)
    merge m:1 provider using "${data_dir}/temp/mkt_share_20132014", assert(1 3) keep(3) nogen
    save "${data_dir}/temp/num_epsd_20132014", replace
    
end

program volume_changes
    syntax, year1(int) year2(int)

    use "${data_dir}/temp/num_epsd_`year2'", clear
    merge 1:1 provider using "${data_dir}/temp/num_epsd_`year1'", nogen
    replace num_epsd_`year2' = 0 if num_epsd_`year2' == .
    replace num_epsd_`year1' = 0 if num_epsd_`year1' == .
    gen a_epsdchg_`year2'_`year1' = ///
        abs(num_epsd_`year2'- num_epsd_`year1')
    gen epsd_change_`year2'_`year1' = num_epsd_`year2'- num_epsd_`year1'
    save "${data_dir}/temp/epsd_change_`year2'_`year1'", replace
    
end

program epsd_change_opt_in

    ** Look within voluntary treatment, see changes in number of episodes by selecting in
    use "$ext/Analysis Data/output/provider_level_data2016_2018.dta", clear
	keep if mandatory == 0 & Treatment == 1

    foreach file in 2014_2013 20162017_20132014 2018_20132014 2018_20162017 {
    	merge 1:1 provider using "${data_dir}/temp/epsd_change_`file'", ///
	    keep(1 3) nogen
    }
	
	summ num_epsd_2018 if Select_Out == 1
    matrix select_in_num_epsd_means = nullmat(select_in_num_epsd_means) \ (`r(mean)' , `r(sd)')
	
	areg num_epsd_2018 Select_In num_epsd_20132014, a(msa) vce(cluster msa)	
    local p_value = 2 * ttail(e(df_r), abs(_b[Select_In]/_se[Select_In]))
    matrix select_in_num_epsd = nullmat(select_in_num_epsd) \ ///
            (_b[Select_In] , _se[Select_In], _b[Select_In]-invt(e(df_r), .975)*_se[Select_In] ///
	    , _b[Select_In ]+ invt(e(df_r), .975)*_se[Select_In] , `p_value')
		
	areg num_epsd_2018 Select_In num_epsd_20162017, a(msa) vce(cluster msa)	
    local p_value = 2 * ttail(e(df_r), abs(_b[Select_In]/_se[Select_In]))
    matrix select_in_num_epsd = nullmat(select_in_num_epsd) \ ///
            (_b[Select_In] , _se[Select_In], _b[Select_In]-invt(e(df_r), .975)*_se[Select_In] ///
	    , _b[Select_In ]+ invt(e(df_r), .975)*_se[Select_In] , `p_value')
		
	areg num_epsd_2018 Select_In num_epsd_20132014 num_epsd_20162017, a(msa) vce(cluster msa)
    local p_value = 2 * ttail(e(df_r), abs(_b[Select_In]/_se[Select_In]))
    matrix select_in_num_epsd = nullmat(select_in_num_epsd) \ ///
            (_b[Select_In] , _se[Select_In], _b[Select_In]-invt(e(df_r), .975)*_se[Select_In] ///
	    , _b[Select_In ]+ invt(e(df_r), .975)*_se[Select_In] , `p_value')

	mat select_in_num_epsd = (select_in_num_epsd_means \ (.,.) \ (.,.) ), select_in_num_epsd


    ** Look within voluntary treatment, see changes in log episodes by selecting in
    use "$ext/Analysis Data/output/provider_level_data2016_2018.dta", clear
	keep if mandatory == 0 & Treatment == 1

    foreach file in 2014_2013 20162017_20132014 2018_20132014 2018_20162017 {
    	merge 1:1 provider using "${data_dir}/temp/epsd_change_`file'", ///
	    keep(1 3) nogen
    }
	gen lnnum_epsd_2018 = ln(num_epsd_2018+0.0001)
	gen lnnum_epsd_20132014 = ln(num_epsd_20132014+0.0001)
	gen lnnum_epsd_20162017 = ln(num_epsd_20162017+0.0001)

	summ lnnum_epsd_2018 if Select_Out == 1
    matrix select_in_lnnum_epsd_means = nullmat(select_in_lnnum_epsd_means) \ (`r(mean)' , `r(sd)')
	
	areg lnnum_epsd_2018 Select_In lnnum_epsd_20132014, a(msa) vce(cluster msa)	
    local p_value = 2 * ttail(e(df_r), abs(_b[Select_In]/_se[Select_In]))
    matrix select_in_lnnum_epsd = nullmat(select_in_lnnum_epsd) \ ///
            (_b[Select_In] , _se[Select_In], _b[Select_In]-invt(e(df_r), .975)*_se[Select_In] ///
	    , _b[Select_In ]+ invt(e(df_r), .975)*_se[Select_In] , `p_value')
		
	areg lnnum_epsd_2018 Select_In lnnum_epsd_20162017, a(msa) vce(cluster msa)	
    local p_value = 2 * ttail(e(df_r), abs(_b[Select_In]/_se[Select_In]))
    matrix select_in_lnnum_epsd = nullmat(select_in_lnnum_epsd) \ ///
            (_b[Select_In] , _se[Select_In], _b[Select_In]-invt(e(df_r), .975)*_se[Select_In] ///
	    , _b[Select_In ]+ invt(e(df_r), .975)*_se[Select_In] , `p_value')
		
	areg lnnum_epsd_2018 Select_In lnnum_epsd_20132014 lnnum_epsd_20162017, a(msa) vce(cluster msa)
    local p_value = 2 * ttail(e(df_r), abs(_b[Select_In]/_se[Select_In]))
    matrix select_in_lnnum_epsd = nullmat(select_in_lnnum_epsd) \ ///
            (_b[Select_In] , _se[Select_In], _b[Select_In]-invt(e(df_r), .975)*_se[Select_In] ///
	    , _b[Select_In ]+ invt(e(df_r), .975)*_se[Select_In] , `p_value')

	mat select_in_lnnum_epsd = (select_in_lnnum_epsd_means \ (.,.) \ (.,.) ), select_in_lnnum_epsd
		
end


program make_tables
	
    foreach mat in select_in_num_epsd select_in_lnnum_epsd {
        clear
        svmat `mat'
        label variable `mat'1 "Mean Value in Control Group"
        label variable `mat'2 "SD"
        label variable `mat'3 "Change with Bundled Payment"
		label variable `mat'4 "S.E."
        label variable `mat'5 "95% CI Lower Bound"
        label variable `mat'6 "95% CI Upper Bound"
        label variable `mat'7 "P-Value"

        gen y_var = "Outcome in 2018" in 1
        replace y_var = "Outcome in 2018" in 2
        replace y_var = "Outcome in 2018" in 3

		gen covariate = "Outcome in 2013-2014" in 1
        replace covariate = "Outcome in 2016-2017" in 2
        replace covariate = "Outcome in 2013-2014, 2016-2017" in 3
		
        order y_var covariate, first
		
        export excel using "../output/tables/TableA1P2P3", ///
            sheet("`mat'") firstrow(varlabels) sheetreplace
    }
end

* Execute
main
