version 15
preliminaries

global data_dir = "[DATA DIR]"
global ext = "[EXT DIR]"

global Utilization = "tot_spend NetPay index_spend inst_pac_spend hha_spend other_spend index_los inst_pac_los"
global Utilization = "$Utilization dschrg_inst_pac dschrg_hha dschrg_home dschrg_other"
global Quality = "thatka_comp er_visit all_cause_readmit"
global PatMix = "lejr_rate cjr_rate elixsum"
global Outcomes = "$Utilization $Quality $PatMix"
global PreYear = "2013 2014"
global AnalysisYear = "2016_2017"

program main

    generate_all_cause_readmission
    generate_thatka_comp
    load_elixsum
    hospital_level_ols
    make_table
    
end

program generate_all_cause_readmission

    foreach year in $PreYear {
        use "$ext/Episode Level Data/output/all_episode_level_data`year'.dta", clear
        keep if drop_bpci ==0 & drop_die == 0 & drop_esrd ==0 & drop_hmo==0 & ///
            drop_mcare==0 & drop_partAB==0 & drop_pps==0
        // the sample is all LEJR that pass all CJR criteria except for readmission (since we 
        // want to summarize the frequency of readmissions for all DRGs we cannot drop the CJR
        // episodes due to LEJR readmission
	
        * Keep only providers from the baseline
	    merge m:1 provider using "$ext/Analysis Data/output/provider_level_data_baseline", ///
	        keep(3) keepusing(provider) nogen
			
        collapse (mean) all_cause_readmit, by(provider)
        rename all_cause_readmit all_cause_readmit_`year'
        save "${data_dir}/temp/all_cause_readmit_`year'", replace
    }
    use "$ext/Episode Level Data/output/all_episode_level_data$AnalysisYear.dta", clear
    keep if drop_bpci ==0 & drop_die == 0 & drop_esrd ==0 & drop_hmo==0 & ///
        drop_mcare==0 & drop_partAB==0 & drop_pps==0

    keep if Final_MSAs == 1

    * Keep only providers from the baseline
    merge m:1 provider using "$ext/Analysis Data/output/provider_level_data_baseline", ///
        keep(3) keepusing(provider) nogen
	rename *, lower
	rename control Control
    unique bene_id if Control == 1 & all_cause_readmit != 0
    global NZC_post_all_cause_readmit = r(sum)	
    
    collapse (mean) all_cause_readmit, by(provider)
    
    rename all_cause_readmit all_cause_readmit_post
    foreach year in $PreYear {
        merge 1:1 provider using "${data_dir}/temp/all_cause_readmit_`year'", assert(1 2 3) keep(3) nogen
    }
    save "${data_dir}/temp/all_cause_readmit_$AnalysisYear", replace

end

program generate_thatka_comp

    foreach year in $PreYear {
        use "$ext/Episode Level Data/output/all_episode_level_data`year'.dta", clear
	    merge 1:1 episode_id using ///
	        "$ext/THATKA Complications/output/thatka_comp`year'.dta", assert(3) keep(3) nogen
        keep if drop_bpci ==0 & drop_esrd ==0 & drop_hmo==0 & ///
            drop_mcare==0 & drop_partAB==0 & drop_pps==0
        // the sample is all LEJR that pass all CJR criteria except for death
	    // and readmission
		
	    * Keep only providers from the baseline
        merge m:1 provider using "$ext/Analysis Data/output/provider_level_data_baseline", ///
            keep(3) keepusing(provider) nogen
			
	    save "${data_dir}/temp/thatka_comp_`year'_loaded", replace
        collapse (mean) thatka_comp = thatka_comp_flag, by(provider)
        rename thatka_comp thatka_comp_`year'
        save "${data_dir}/temp/thatka_comp_`year'", replace
    }
	
		
    use "$ext/Episode Level Data/output/all_episode_level_data$AnalysisYear.dta", clear
    merge 1:1 episode_id using ///
        "$ext/THATKA Complications/output/thatka_comp$AnalysisYear.dta", assert(3) keep(3) nogen
    keep if drop_bpci ==0 & drop_esrd ==0 & drop_hmo==0 & ///
        drop_mcare==0 & drop_partAB==0 & drop_pps==0
        // the sample is all LEJR that pass all CJR criteria except for death
	    // and readmission
    keep if Final_MSAs == 1
    
	* Keep only providers from the baseline
    merge m:1 provider using "$ext/Analysis Data/output/provider_level_data_baseline", ///
        keep(3) keepusing(provider) nogen

	rename *, lower
	rename control Control
    unique bene_id if Control == 1 & thatka_comp != 0
    global NZC_post_thatka_comp = r(sum)
    
    collapse (mean) thatka_comp = thatka_comp_flag, by(provider)
	
    rename thatka_comp thatka_comp_post
	
    foreach year in $PreYear {
        merge 1:1 provider using "${data_dir}/temp/thatka_comp_`year'", ///
	    assert(1 2 3) keep(1 2 3) keepusing(thatka_comp_`year') nogen
    }
    save "${data_dir}/temp/thatka_comp_$AnalysisYear", replace

end

program load_elixsum

    foreach year in $PreYear {
        use "$ext/Episode Level Data/output/all_episode_level_data`year'.dta", clear
	keep if cjr_sample == 1 & OrigElig == 1
        merge 1:1 episode_id using "$ext/Elixhauser/output/elix`year'.dta", ///
	    assert(2 3) keep(3) nogen
		
	* Keep only providers from the baseline
    merge m:1 provider using "$ext/Analysis Data/output/provider_level_data_baseline", ///
        keep(3) keepusing(provider) nogen
			
	collapse (mean) elixsum, by(provider)
        rename elixsum elixsum_`year'
        
        save "${data_dir}/temp/elix_`year'", replace
    }
    
    use if cjr_sample == 1 & OrigElig == 1 using ///
        "$ext/Episode Level Data/output/all_episode_level_data$AnalysisYear.dta", clear
    merge 1:1 episode_id using "$ext/Elixhauser/output/elix$AnalysisYear.dta", ///
	assert(2 3) keep(3) nogen
   
    keep if Final_MSAs == 1		
    
	* Keep only providers from the baseline
    merge m:1 provider using "$ext/Analysis Data/output/provider_level_data_baseline", ///
        keep(3) keepusing(provider) nogen
    
	rename *, lower
	rename control Control
    unique bene_id if Control == 1 & elixsum != 0
    global NZC_post_elixsum = r(sum)
    
    collapse (mean) elixsum, by(provider)
	
	rename elixsum elixsum_post
	
    foreach year in $PreYear {
        merge 1:1 provider using "${data_dir}/temp/elix_`year'", ///
	    assert(1 2 3) keep(1 2 3) keepusing(elixsum_`year') nogen
    }
    save "${data_dir}/temp/elix_$AnalysisYear", replace

end


program hospital_level_ols

    use "$ext/Analysis Data/output/provider_level_data$AnalysisYear", clear

    merge 1:1 provider using "${data_dir}/temp/all_cause_readmit_$AnalysisYear", assert(2 3) keep(3) nogen
    merge 1:1 provider using "${data_dir}/temp/elix_$AnalysisYear", assert(2 3) keep(3) nogen
    merge 1:1 provider using "${data_dir}/temp/thatka_comp_$AnalysisYear", assert(2 3) keep(3) nogen
	merge 1:1 provider using "${data_dir}/temp/ext_outcomes_$AnalysisYear",assert(2 3) keep(3) nogen
    rename lejr_rate lejr_rate_post
	rename cjr_rate cjr_rate_post
	
    foreach outcome in $Outcomes {
	
	    * Weighted
	    summ `outcome'_post [aw = num_epsd_post] if Control == 1
        matrix analysis_means_w = nullmat(analysis_means_w) \ (`r(mean)' \ `r(sd)' \ .)
	    mat N_mat = nullmat(N_mat) \ (${NC_post} , ${NZC_post_`outcome'})

        reg `outcome'_post Treatment i.strata `outcome'_2013 `outcome'_2014 [aw = num_epsd_post], vce(cluster msa)
	    local p_value = 2 * ttail(e(df_r), abs(_b[Treatment]/_se[Treatment]))
        matrix analysis_ols_w = nullmat(analysis_ols_w) \ ///
            (_b[Treatment] \ _se[Treatment] \ `p_value')
			
    }
    matrix ols_hospitals_w = analysis_means_w, analysis_ols_w

end

program table_table


    foreach mat in ols_hospitals_w {
        clear
        svmat `mat'
        label variable `mat'1 "Mean Value in Control Group"
        label variable `mat'2 "Change with Bundled Payment"
	

        gen varname = "Total Episode Spending" in 1
        replace varname = "Total Episode Spending Net of Reconciliation" in 4
        replace varname = "Episode Spending in Index Admission" in 7
        replace varname = "Episode Spending in Institutional PAC Admission" in 10
        replace varname = "Episode Spending in Home Health" in 13
        replace varname = "Other Episode Spending" in 16
	    replace varname = "Number of Days in Index Admission" in 19
        replace varname = "Number of Days in Institutional PAC" in 22
        replace varname = "Share Discharged to Institutional PAC" in 25
        replace varname = "Share Discharged to Home Health Agency" in 28
        replace varname = "Share Discharged Home" in 31
        replace varname = "Share Discharged to Other" in 34
        replace varname = "Complication Rate" in 37
        replace varname = "ER Visit During Episode" in 40
        replace varname = "90-day All Cause Readmission Rate" in 43
        replace varname = "LEJR Admissions (per 1,000 enrollees)" in 46
        replace varname = "CJR-eligible LEJR Admissions (per 1,000 enrollees)" in 49
        replace varname = "Elixhauser Comorbidity Score" in 52
		
        order varname, first
		
        export excel using "../output/tables/TableA3P3", ///
            sheet("`mat'") firstrow(varlabels) sheetreplace
    }
    
end


* Execute
main
