version 15
set more off

preliminaries

global data_dir = "[DATA DIR]"
global ext = "[EXT DIR]"

global Outcomes = "tot_spend inst_pac_spend dschrg_inst_pac"

program main
    analysis_over_time
    make_table
end

program analysis_over_time
    
	** All MSAs **
	foreach year in 2016 2017 2018 {
		foreach half in first second {
		use "$ext/Analysis Data/output/episode_level_data2016_2018.dta", clear
        egen num_bene_post = tag(bene_id provider)
        keep if Final_MSAs == 1   
		
		keep if year(admsn_dt) == `year'
		if "`half'"=="first" {
			keep if month(admsn_dt) <= 6
			gen temp_month = month(admsn_dt)
			sum temp_month
		}
		if "`half'"=="second" {
	        keep if month(admsn_dt) >= 7
			gen temp_month = month(admsn_dt)
			sum temp_month
		}
		foreach var in $Outcomes {
			qui: count if num_bene_post == 1 & Control == 1 
			global NC_`var' = `r(N)'
			qui: unique bene_id if `var'!=0 & Control == 1 
			global NZC_`var' = `r(sum)'	
		}

		collapse (sum) num_bene_post (mean) $Outcomes Control Treatment strata *_2013 *_2014, by(msa)
		xi i.strata, pref(_) 
		
		 * Means (Control)
		foreach outcome in $Outcomes {
			summ `outcome' if Control == 1
			matrix `outcome'_means = nullmat(`outcome'_means) \ (`r(mean)' , `r(sd)')
			mat `outcome'_N = nullmat(`outcome'_N) \ (${NC_`outcome'} , ${NZC_`outcome'})
		}

		* OLS
		foreach outcome in $Outcomes {

			reg `outcome' Treatment _strata* `outcome'_2013 `outcome'_2014, r
			local p_value = 2 * ttail(e(df_r), abs(_b[Treatment]/_se[Treatment]))
			matrix `outcome'_ols = nullmat(`outcome'_ols) \ ///
				(_b[Treatment] , _se[Treatment], _b[Treatment]-invt(e(df_r), .975)*_se[Treatment] ///
			, _b[Treatment ]+ invt(e(df_r), .975)*_se[Treatment] , `p_value')
			
		}
	}
	}
		
	foreach outcome in $Outcomes {
		mat `outcome' = `outcome'_means, `outcome'_ols, `outcome'_N
	}
	mat analysis_over_time = tot_spend \ inst_pac_spend \ dschrg_inst_pac
	

    ** Mandatory MSAs **
	foreach outcome in $Outcomes {
		capture mat drop `outcome'
		capture mat drop `outcome'_means
		capture mat drop `outcome'_ols
		capture mat drop `outcome'_N
	}
    foreach year in 2016 2017 2018 {
		foreach half in first second {
		use "$ext/Analysis Data/output/episode_level_data2016_2018.dta", clear
	    merge m:1 provider using "$ext/Analysis Data/output/provider_level_data2016_2018.dta", assert(3) keepusing(mandatory) nogen
        egen num_bene_post = tag(bene_id provider)
        keep if Final_MSAs == 1   
		
        * keep only mandatory MSAs
		keep if mandatory == 1
		
		keep if year(admsn_dt) == `year'
		if "`half'"=="first" {
			keep if month(admsn_dt) <= 6
			gen temp_month = month(admsn_dt)
			sum temp_month
		}
		if "`half'"=="second" {
	        keep if month(admsn_dt) >= 7
			gen temp_month = month(admsn_dt)
			sum temp_month
		}
		foreach var in $Outcomes {
			qui: count if num_bene_post == 1 & Control == 1 & mandatory == 1
			global NC_`var' = `r(N)'
			qui: unique bene_id if `var'!=0 & Control == 1 & mandatory == 1
			global NZC_`var' = `r(sum)'	
		}

		collapse (sum) num_bene_post (mean) $Outcomes mandatory Control Treatment strata *_2013 *_2014, by(msa)
		xi i.strata, pref(_) 
		
		 * Means (Control)
		foreach outcome in $Outcomes {
			summ `outcome' if Control == 1
			matrix `outcome'_means = nullmat(`outcome'_means) \ (`r(mean)' , `r(sd)')
			mat `outcome'_N = nullmat(`outcome'_N) \ (${NC_`outcome'} , ${NZC_`outcome'})
		}

		* OLS
		foreach outcome in $Outcomes {

			reg `outcome' Treatment _strata* `outcome'_2013 `outcome'_2014, r
			local p_value = 2 * ttail(e(df_r), abs(_b[Treatment]/_se[Treatment]))
			matrix `outcome'_ols = nullmat(`outcome'_ols) \ ///
				(_b[Treatment] , _se[Treatment], _b[Treatment]-invt(e(df_r), .975)*_se[Treatment] ///
			, _b[Treatment ]+ invt(e(df_r), .975)*_se[Treatment] , `p_value')
			
		}
	}
	}
		
	foreach outcome in $Outcomes {
		mat `outcome' = `outcome'_means, `outcome'_ols, `outcome'_N
	}
	mat analysis_man_over_time = tot_spend \ inst_pac_spend \ dschrg_inst_pac

	** Voluntary Msas **
    foreach outcome in $Outcomes {
		capture mat drop `outcome'
		capture mat drop `outcome'_means
		capture mat drop `outcome'_ols
		capture mat drop `outcome'_N
	}
	
    foreach year in 2016 2017 2018 {
		foreach half in first second {
		use "$ext/Analysis Data/output/episode_level_data2016_2018.dta", clear
	    merge m:1 provider using "$ext/Analysis Data/output/provider_level_data2016_2018.dta", assert(3) keepusing(mandatory) nogen
        egen num_bene_post = tag(bene_id provider)
        keep if Final_MSAs == 1   
		
        * keep only voluntary MSAs
		keep if mandatory == 0
		
		keep if year(admsn_dt) == `year'
	    if "`half'"=="first" {
			keep if month(admsn_dt) <= 6
			gen temp_month = month(admsn_dt)
			sum temp_month
		}
		if "`half'"=="second" {
	        keep if month(admsn_dt) >= 7
			gen temp_month = month(admsn_dt)
			sum temp_month
		}
		foreach var in $Outcomes {
			qui: count if num_bene_post == 1 & Control == 1 & mandatory == 0
			global NC_`var' = `r(N)'
			qui: unique bene_id if `var'!=0 & Control == 1 & mandatory == 0
			global NZC_`var' = `r(sum)'	
		}

		collapse (sum) num_bene_post (mean) $Outcomes mandatory Control Treatment strata *_2013 *_2014, by(msa)
		xi i.strata, pref(_) 
		
		 * Means (Control)
		foreach outcome in $Outcomes {
			summ `outcome' if Control == 1
			matrix `outcome'_means = nullmat(`outcome'_means) \ (`r(mean)' , `r(sd)')
			mat `outcome'_N = nullmat(`outcome'_N) \ (${NC_`outcome'} , ${NZC_`outcome'})
		}

		* OLS
		foreach outcome in $Outcomes {

			reg `outcome' Treatment _strata* `outcome'_2013 `outcome'_2014, r
			local p_value = 2 * ttail(e(df_r), abs(_b[Treatment]/_se[Treatment]))
			matrix `outcome'_ols = nullmat(`outcome'_ols) \ ///
				(_b[Treatment] , _se[Treatment], _b[Treatment]-invt(e(df_r), .975)*_se[Treatment] ///
			, _b[Treatment ]+ invt(e(df_r), .975)*_se[Treatment] , `p_value')
			
		}
	}
	}	
	foreach outcome in $Outcomes {
		mat `outcome' = `outcome'_means, `outcome'_ols, `outcome'_N
	}
	mat analysis_vol_over_time = tot_spend \ inst_pac_spend \ dschrg_inst_pac
	
end


program make_table
     
    foreach mat in analysis_over_time analysis_man_over_time analysis_vol_over_time {
        clear
        svmat `mat'
        label variable `mat'1 "Mean Value in Control Group"
        label variable `mat'2 "SD"
        label variable `mat'3 "Change with Bundled Payment"
		label variable `mat'4 "SE"
        label variable `mat'5 "95% CI Lower Bound"
        label variable `mat'6 "95% CI Upper Bound"
        label variable `mat'7 "P-Value"
	    label variable `mat'8 "Denominator"
	    label variable `mat'9 "Non Zero Numerator"

        gen varname = "Total Episode Claims" in 1
        replace varname = "Claims for Institutional PAC" in 7
        replace varname = "Share Discharged to Institutional PAC" in 13
		
		gen year = "2016 First Half" if mod(_n,6) == 1
		replace year = "2016 Second Half" if mod(_n,6) == 2
		replace year = "2017 First Half" if mod(_n,6) == 3
		replace year = "2017 Second Half" if mod(_n,6) == 4
		replace year = "2018 First Half" if mod(_n,6) == 5
		replace year = "2018 Second Half" if mod(_n,6) == 0
		
        order varname year, first
        export excel using "../output/tables/TableA3", ///
            sheet("`mat'") firstrow(varlabels) sheetreplace
    }
	
end    

* Execute
main