version 16
set more off
preliminaries
set maxvar 10000
global data_dir = "/projects/active/14593/idata/Project_3/YJi/analysis/Heterogeneity in Level and Slope"
global ext = "/projects/active/14593/idata/Project_3/YJi/derived"
global Outcomes = "tot_spend inst_pac_spend dschrg_inst_pac"

** Hospital treatment effect, with hospital specific trend **

program main

    load_data
	generate_slopes
    bivariate_regs
    
end

program load_data

        use "$ext/Analysis Data/output/episode_level_data2016_2017.dta", clear
    merge m:1 provider using  "$ext/Analysis Data/output/provider_level_data2016_2017.dta", ///
        keep(3) keepusing(mandatory num_epsd_pre) nogen
		
	* Keep only providers from the baseline
    merge m:1 provider using "$ext/Analysis Data/output/provider_level_data_baseline", ///
        keep(3) keepusing(provider) nogen
		
	* Merge with Elixhauser
    merge m:1 episode_id using "$ext/Elixhauser/output/elix2016_2017.dta", ///
        assert(2 3) keep(3) keepusing(elixsum) nogen
		
    qui summ bene_age, det
	local mincut = `r(min)' - 1
	local maxcut = `r(max)' + 1
    egen age_bins = cut(bene_age), at(`mincut' 55 60 65 70 75 80 85 90 `maxcut')
    destring bene_race, replace
    gen female = (bene_sex == "2")
	gen white = (bene_race == 1)
    gen major_comps = (drg_cd == "469")
    gen disabled = (bene_orec == "1"|bene_orec == "3")

	collapse (mean) age female white major_comps disabled /// 
        elixsum hip_fracture num_epsd_pre, by(provider)
		
	destring provider, gen(provider_num)	
	save "../temp/patient_chars", replace
	
    use "$ext/Analysis Data/output/provider_level_data2016_2017.dta", clear
    merge 1:1 provider using "$ext/Analysis Data/output/provider_level_data_baseline.dta", ///
	    keep(3) nogen
    ** Generate interactions of Treatment dummy and hospital dummies
    
    sort mandatory Select_In Select_Out provider
    bys mandatory Select_In Select_Out: gen Num = _n 
    
    sum Num if Select_In ==1 & mandatory ==0
    
    forv i = 1/`r(max)' {
        gen In_Treat_`i' = (Num == `i' & Select_In ==1 & mandatory ==0)
    }

    sum Num if Select_Out ==1 & mandatory ==0
    
    forv i = 1/`r(max)' {
        gen Out_Treat_`i' = (Num == `i' & Select_Out ==1 & mandatory ==0)
    }
    
	sort mandatory Treatment provider
	by mandatory Treatment: gen Num2 = _n if mandatory == 1 & Treatment == 1 
	    // do not drop (rural/low volume) and include all mandaotry
    sum Num2 
    
    forv i = 1/`r(max)' {
        gen Man_Treat_`i' = (Num2 == `i' & mandatory ==1  & Treatment == 1)
    } 
	
	xi i.provider, pref(_P) noomit
	keep provider mandatory Select_In Select_Out _P* In_Treat* Out_Treat* Man_Treat* Treatment strata Num Num2 num_epsd_post msa *_2013 *_2014
    save "${data_dir}/temp/data_loaded_pre_post_dummies", replace
	
	** Load hospital-year panel

	* 2017
	use "$ext/Analysis Data/output/episode_level_data2016_2017.dta", clear
	merge m:1 provider using "$ext/Analysis Data/output/provider_level_data_baseline.dta", ///
	    keepusing(provider) keep(3) nogen
    keep if admsn_dt > date("September 15 2016", "MDY")
	gen num_epsd = 1
	egen num_bene = tag(bene_id)
	collapse (mean) $Outcomes (sum) num_epsd num_bene, by(provider)
	gen year = 2017
	save "${data_dir}/temp/provider_level_means_2017", replace
	
	* 2016
	use "$ext/Analysis Data/output/episode_level_data2016_2017.dta", clear	
	merge m:1 provider using "$ext/Analysis Data/output/provider_level_data_baseline.dta", ///
	    keepusing(provider) keep(3) nogen
	keep if admsn_dt <= date("September 15 2016", "MDY")
	gen num_epsd = 1
	egen num_bene = tag(bene_id)
	collapse (mean) $Outcomes (sum) num_epsd num_bene, by(provider)
	gen year = 2016
	save "${data_dir}/temp/provider_level_means_2016", replace
	
	
	* 2010-2014
	foreach year in 2010 2011 2012 2013 2014 {
		use "$ext/Episode Level Data/output/all_episode_level_data`year'.dta", clear
	
		keep if cjr_sample == 1
		merge m:1 provider using ///
			"$ext/Analysis Data/output/provider_level_data_baseline.dta", keep(2 3) ///
			keepusing(provider) nogen

		gen inst_pac_oop = irf_oop + ltch_oop + snf_oop

		foreach type in tot inst_pac {
			gen `type'_spend = `type'_pay + `type'_oop
		}
		foreach outcome in $Outcomes {
			replace `outcome' = 0 if `outcome' == .
		}
		gen num_epsd = 1
		egen num_bene = tag(BENE_ID)
		collapse (mean) $Outcomes (sum) num_epsd num_bene, by(provider)
		gen year = `year'
		save "${data_dir}/temp/provider_level_means_`year'", replace
	}

	
	* Combine
	clear
	foreach year in 2010 2011 2012 2013 2014 2016 2017 {
	
	    append using "${data_dir}/temp/provider_level_means_`year'"
	
	}
	
	* Merge in dummies with hospital-year panel
	merge m:1 provider using "${data_dir}/temp/data_loaded_pre_post_dummies", ///
	    assert(3) nogen

	gen sort_order = year if year >= 2013
	replace sort_order = year + 1000 if year < 2013 
	    // the pre years do not have all the hosps we use the 2013 sample (baseline)
	sort sort_order provider
	gen Num3_temp = _n if year == 2013 // 1455
	bys provider: egen Num3 = max(Num3_temp)
    summ Num3
    forv i = 1/`r(max)' {
	    gen HY_`i' = .
	    foreach year in 2010 2011 2012 2013 2014 2016 2017 {
	        replace HY_`i' = `year' if Num3 == `i' & year == `year'
		}
		replace HY_`i' = 0 if Num3 != `i' 
		assert HY_`i' != .
	}
	
	drop Num3_temp
	
	* Make the indicators Post X treatment hospital dummies
	foreach var of varlist In_Treat* Out_Treat* Man_Treat* {
	    replace `var' = 0 if year < 2016
	}
	
    save "${data_dir}/temp/hospital_year_panel_loaded", replace
		
end


program generate_slopes

    	    
    foreach outcome in $Outcomes {
	
        use "${data_dir}/temp/hospital_year_panel_loaded", clear
	    destring provider, gen(provider_num)
		* Weighted

		reg `outcome' _Pprovider_* i.year HY_* In_Treat* Out_Treat* Man_Treat* ///
			[aw = num_epsd_post], vce(cluster msa)
		
		qui: sum Num if Select_In ==1 & mandatory ==0
		local max = `r(max)'
		
		forv i = 1/`max' {
			qui: sum num_epsd_post if In_Treat_`i'==1
			local num_epsd_post = `r(mean)'
			summ provider_num if In_Treat_`i'==1 
			local provider = `r(mean)'
			mat In_Treat_`outcome' = nullmat(In_Treat_`outcome') \ ///
			    (_b[In_Treat_`i'], `num_epsd_post', 1, `provider')
		}

		qui: sum Num if Select_Out ==1 & mandatory ==0
		local max = `r(max)'

		forv i = 1/`max' {
			qui: sum num_epsd_post if Out_Treat_`i'==1
			local num_epsd_post = `r(mean)'
			summ provider_num if Out_Treat_`i'==1 
			local provider = `r(mean)'
			mat Out_Treat_`outcome' = nullmat(Out_Treat_`outcome') \ ///
			    (_b[Out_Treat_`i'], `num_epsd_post', 0, `provider')
		}
		
		qui: sum Num2 if mandatory == 1 & Treatment == 1
		local max = `r(max)'

		forv i = 1/`max' {
			qui: sum num_epsd_post if Man_Treat_`i'==1
			local num_epsd_post = `r(mean)'
			summ provider_num if Man_Treat_`i'==1 
			local provider = `r(mean)'
			mat Man_Treat_`outcome' = nullmat(Man_Treat_`outcome') \ ///
			    (_b[Man_Treat_`i'], `num_epsd_post', 0, `provider')
		}
        matrix Hospital_Treat_`outcome' = In_Treat_`outcome' \ Out_Treat_`outcome' \ Man_Treat_`outcome'
    
        mat colnames Hospital_Treat_`outcome' = beta num_epsd_post selection provider
    
        clear
    
        svmat Hospital_Treat_`outcome', names(col)
		save "${data_dir}/temp/regression_estimates_`outcome'.dta", replace
	}
end

program bivariate_regs    
	foreach outcome in $Outcomes {
        use "${data_dir}/temp/regression_estimates_`outcome'.dta", clear
		rename provider provider_num
	    * Merge in Pat Chars
        merge 1:1 provider_num using "../temp/patient_chars", ///
            assert(2 3) keep(3) nogen	
		merge 1:1 provider using "$ext/AHA/output/aha", assert(1 2 3) ///
        keep(1 3) nogen
	    gen ownership = 1 if prov_fp == 1
	    replace ownership = 2 if prov_np == 1
	    replace ownership = 3 if ownership == .
		
        * Merge with CQS
        destring provider, replace
        merge 1:1 provider using "$ext/CQS/output/quality_measures.dta", ///
            assert(1 2 3) keep(1 3) keepusing(cqs) nogen
		summ beta [aw=num_epsd_post]
		matrix biv_slope_`outcome' = nullmat(biv_slope_`outcome') \ (`r(mean)' , `r(sd)')
		foreach xvar in num_epsd_pre cqs prov_beds prov_coth {
	        reg beta `xvar' [aw = num_epsd_post], robust
		    matrix biv_slope_`outcome'  = nullmat(biv_slope_`outcome') \ ( _b[`xvar'], _se[`xvar'])
		}
		reg beta prov_fp prov_np [aw=num_epsd_post], robust
		matrix biv_slope_`outcome' = nullmat(biv_slope_`outcome') \ (_b[prov_fp], _se[prov_fp])
		matrix biv_slope_`outcome' = nullmat(biv_slope_`outcome') \ (_b[prov_np], _se[prov_np])

	}
	
	matrix biv_slopes = biv_slope_tot_spend, biv_slope_inst_pac_spend, biv_slope_dschrg_inst_pac
    mat list biv_slopes	
	
end



* Execute
main
