version 16
set more off
preliminaries
set maxvar 10000
global data_dir = "[DATA DIR]"
global ext = "[EXT DIR]"
global Outcomes = "tot_spend inst_pac_spend dschrg_inst_pac"

** Hospital treatment effect, with hospital specific trend **

program main

    load_data
    hospital_level_ols_msa_cluster
    make_table
    
end

program load_data

    
    use "$ext/Analysis Data/output/provider_level_data2016_2017.dta", clear
    merge 1:1 provider using "$ext/Analysis Data/output/provider_level_data_baseline.dta", ///
	    keep(3) nogen
		
    ** Generate interactions of Treatment dummy and hospital dummies
    
    sort mandatory Select_In Select_Out provider
    bys mandatory Select_In Select_Out: gen Num = _n 
    
    sum Num if Select_In ==1 & mandatory ==0
    
    forv i = 1/`r(max)' {
        gen In_Treat_`i' = (Num == `i' & Select_In ==1 & mandatory ==0)
    }

    sum Num if Select_Out ==1 & mandatory ==0
    
    forv i = 1/`r(max)' {
        gen Out_Treat_`i' = (Num == `i' & Select_Out ==1 & mandatory ==0)
    }
    
	sort mandatory Treatment provider
	by mandatory Treatment: gen Num2 = _n if mandatory == 1 & Treatment == 1 

    sum Num2 
    
    forv i = 1/`r(max)' {
        gen Man_Treat_`i' = (Num2 == `i' & mandatory ==1  & Treatment == 1)
    } 
	
	xi i.provider, pref(_P) noomit
	keep provider mandatory Select_In Select_Out _P* In_Treat* Out_Treat* Man_Treat* Treatment strata Num Num2 num_epsd_post msa
    save "${data_dir}/temp/data_loaded_pre_post_dummies", replace
	
	** Load hospital-year panel

	* 2017
	use "$ext/Analysis Data/output/episode_level_data2016_2017.dta", clear
	merge m:1 provider using "$ext/Analysis Data/output/provider_level_data_baseline.dta", ///
	    keepusing(provider) keep(3) nogen
    keep if admsn_dt > date("September 15 2016", "MDY")
	gen num_epsd = 1
	egen num_bene = tag(bene_id)
	collapse (mean) $Outcomes (sum) num_epsd num_bene, by(provider)
	gen year = 2017
	save "${data_dir}/temp/provider_level_means_2017", replace
	
	* 2016
	use "$ext/Analysis Data/output/episode_level_data2016_2017.dta", clear	
	merge m:1 provider using "$ext/Analysis Data/output/provider_level_data_baseline.dta", ///
	    keepusing(provider) keep(3) nogen
	keep if admsn_dt <= date("September 15 2016", "MDY")
	gen num_epsd = 1
	egen num_bene = tag(bene_id)
	collapse (mean) $Outcomes (sum) num_epsd num_bene, by(provider)
	gen year = 2016
	save "${data_dir}/temp/provider_level_means_2016", replace
	
	
	* 2010-2014
	foreach year in 2010 2011 2012 2013 2014 {
		use "$ext/Episode Level Data/output/all_episode_level_data`year'.dta", clear
	
		keep if cjr_sample == 1
		merge m:1 provider using ///
			"$ext/Analysis Data/output/provider_level_data_baseline.dta", keep(2 3) ///
			keepusing(provider) nogen

		gen inst_pac_oop = irf_oop + ltch_oop + snf_oop

		foreach type in tot inst_pac {
			gen `type'_spend = `type'_pay + `type'_oop
		}
		foreach outcome in $Outcomes {
			replace `outcome' = 0 if `outcome' == .
		}
		gen num_epsd = 1
		egen num_bene = tag(BENE_ID)
		collapse (mean) $Outcomes (sum) num_epsd num_bene, by(provider)
		gen year = `year'
		save "${data_dir}/temp/provider_level_means_`year'", replace
	}

	
	* Combine
	clear
	foreach year in 2010 2011 2012 2013 2014 2016 2017 {
	
	    append using "${data_dir}/temp/provider_level_means_`year'"
	
	}
	
	* Merge in dummies with hospital-year panel
	merge m:1 provider using "${data_dir}/temp/data_loaded_pre_post_dummies", ///
	    assert(3) nogen

	gen sort_order = year if year >= 2013
	replace sort_order = year + 1000 if year < 2013 
	sort sort_order provider
	gen Num3_temp = _n if year == 2013
	bys provider: egen Num3 = max(Num3_temp)
    summ Num3
    forv i = 1/`r(max)' {
	    gen HY_`i' = .
	    foreach year in 2010 2011 2012 2013 2014 2016 2017 {
	        replace HY_`i' = `year' if Num3 == `i' & year == `year'
		}
		replace HY_`i' = 0 if Num3 != `i' 
		assert HY_`i' != .
	}
	
	drop Num3_temp
	
	* Make the indicators Post X treatment hospital dummies
	foreach var of varlist In_Treat* Out_Treat* Man_Treat* {
	    replace `var' = 0 if year < 2016
	}
    save "${data_dir}/temp/hospital_year_panel_loaded", replace
		
end

program hospital_level_ols_msa_cluster
		    
    foreach outcome in $Outcomes {
	
        use "${data_dir}/temp/hospital_year_panel_loaded", clear
	
		* Weighted

		reg `outcome' _Pprovider_* i.year HY_* In_Treat* Out_Treat* Man_Treat* ///
			[aw = num_epsd_post], vce(cluster msa)
		
		qui: sum Num if Select_In ==1 & mandatory ==0
		local max = `r(max)'
		
		forv i = 1/`max' {
			qui: sum num_epsd_post if In_Treat_`i'==1
			local num_epsd_post = `r(mean)'
			summ msa if In_Treat_`i'==1 
			local msa = `r(mean)'
			mat In_Treat_`outcome' = nullmat(In_Treat_`outcome') \ ///
			    (_b[In_Treat_`i'], `num_epsd_post', 1, `msa')
		}

		qui: sum Num if Select_Out ==1 & mandatory ==0
		local max = `r(max)'

		forv i = 1/`max' {
			qui: sum num_epsd_post if Out_Treat_`i'==1
			local num_epsd_post = `r(mean)'
			summ msa if Out_Treat_`i'==1 
			local msa = `r(mean)'
			mat Out_Treat_`outcome' = nullmat(Out_Treat_`outcome') \ ///
			    (_b[Out_Treat_`i'], `num_epsd_post', 0, `msa')
		}
		
		qui: sum Num2 if mandatory == 1 & Treatment == 1
		local max = `r(max)'

		forv i = 1/`max' {
			qui: sum num_epsd_post if Man_Treat_`i'==1
			local num_epsd_post = `r(mean)'
			summ msa if Man_Treat_`i'==1 
			local msa = `r(mean)'
			mat Man_Treat_`outcome' = nullmat(Man_Treat_`outcome') \ ///
			    (_b[Man_Treat_`i'], `num_epsd_post', 0, `msa')
		}
    
   
        matrix In_Out_Treat_`outcome' = In_Treat_`outcome' \ Out_Treat_`outcome'
        matrix Hospital_Treat_`outcome' = In_Treat_`outcome' \ Out_Treat_`outcome' \ Man_Treat_`outcome'
    
        mat colnames In_Out_Treat_`outcome' = beta num_epsd_post selection msa
    
        clear
    
        svmat In_Out_Treat_`outcome', names(col)
    
        save "${data_dir}/temp/regression_estimates_`outcome'.dta", replace
	
	}
		
    * Weighted	
	foreach outcome in $Outcomes{
        use  "${data_dir}/temp/regression_estimates_`outcome'.dta", clear
	    summ beta [aw = num_epsd_post] if selection == 1
	    mat summ_treat_ww_`outcome' = nullmat(summ_treat_ww_`outcome') , (`r(mean)' \ `r(sd)')
	    summ beta [aw = num_epsd_post] if selection == 0
	    mat summ_treat_ww_`outcome' = nullmat(summ_treat_ww_`outcome') , (`r(mean)' \ `r(sd)')

	    reg beta selection [aw = num_epsd_post], r
	    local p_val_r = 2 * ttail(e(df_r), abs(_b[selection]/_se[selection]))

	    reg beta selection [aw = num_epsd_post]
	    local p_val = 2 * ttail(e(df_r), abs(_b[selection]/_se[selection]))

	    mat summ_treat_ww_`outcome' = nullmat(summ_treat_ww_`outcome') , ((`p_val', `p_val_r') \ (. , .) )
    }
    mat summ_treatment_ww_panel = summ_treat_ww_tot_spend \ ///
	    summ_treat_ww_inst_pac_spend \ summ_treat_ww_dschrg_inst_pac  
		
end

program make_table

    * Generate Table A6 Panel 2 (Panel 1 replicates Table 3 Panel 2)
    matrix summ_treatment_ww_panel =  summ_treatment_ww_panel 
    foreach mat in summ_treatment_ww_panel {
        clear
        svmat `mat'
        label variable `mat'1 "Mean among Hospital Selected In"
        label variable `mat'2 "Mean among Hospital Selected Out"
        label variable `mat'3 "P-Value of Difference in Means"
        label variable `mat'4 "P-Value of Difference in Means (Robust)"

        gen varname = "Change in Total Episode Spending" in 1
        replace varname = "Change in Institutional PAC Spending" in 3
        replace varname = "Change in Share Discharged to Institutional PAC" in 5
	    
		gen rows = "Mean of Estimates" if inlist(_n, 1, 3, 5)
        replace rows = "S.D. of Estimates" if inlist(_n, 2, 4, 6)
		
        order varname rows, first
        export excel using "../output/tables/TableA6", ///
            sheet("`mat'") firstrow(varlabels) sheetreplace
    }
    
end

* Execute
main